import argparse
import time
from decimal import Decimal
import sys
import platform
if platform.system()=="Windows":
    sys.path.append("ui/")
    sys.path.append("images/")
else:
    sys.path.append("/usr/lib/xulpymoney")
from PyQt5.QtWidgets import QApplication
from PyQt5.QtCore import QUrl,  QEventLoop
from PyQt5.QtWebEngineWidgets import QWebEngineView,  QWebEngineProfile
from xulpymoney.libxulpymoneyfunctions import string2date, string2datetime
from xulpymoney.libxulpymoneytypes import eProductType

class OHCL:
    def __init__(self,isin, xulpymoney):
        self.date=None
        self.open=None
        self.close=None
        self.high=None
        self.low=None
        self.isin=isin
        self.xulpymoney=xulpymoney

    def init__from_html_line(self,line,  productype):
        """
        Returns None if fails    
        """
        try:
            line=line.replace(' class="Ult"', "")#Quita anomalía en td
            line=line.split('"center">')[1]#Removes beginning
            line=line[:-5]#Removes end
            line=line.replace(".", "")#Elimina ceros de miles
            l=line.split("</td><td>")#Arr
            self.date=string2date(l[0], type=2)
            if productype==eProductType.Share:
                self.close=Decimal(l[1].replace(",","."))
                self.open=Decimal(l[2].replace(",","."))
                self.high=Decimal(l[6].replace(",","."))
                self.low=Decimal(l[7].replace(",","."))
            elif productype==eProductType.ETF:
                self.close=Decimal(l[8].replace(",","."))
                self.open=Decimal(l[4].replace(",","."))
                self.high=Decimal(l[5].replace(",","."))
                self.low=Decimal(l[6].replace(",","."))
            elif productype==eProductType.Index:
                self.close=Decimal(l[1].replace(",","."))
                self.open=Decimal(l[2].replace(",","."))
                self.high=Decimal(l[3].replace(",","."))
                self.low=Decimal(l[4].replace(",","."))
            return self
        except:
            print ("ERROR | OHCL COULDN'T HAVE BEING  GENERATED | {}".format(line))
            return None

    def __repr__(self):
        if self.xulpymoney!=None:
            return "OHCL | XULPYMONEY | {} | {} | {} | {} | {} | {}".format(self.xulpymoney, self.date, self.open,self.high,self.close,self.low)
        else:
            return "OHCL | STOCKMARKET | ES | ISIN | {} | {} | {} | {} | {} | {}".format(self.isin, self.date, self.open,self.high,self.close,self.low)

class SetOHCL:
    def __init__(self, isin, xulpymoney, productype):
        self.arr=[]
        self.isin=isin# Is a value, not a list
        self.xulpymoney=xulpymoney#Is a value, not a list
        self.productype=productype

    def searchQuotesInHtml(self,html):
        """Looks for quotes line in html and creates ohcl"""
        for line in html.split("\n"):
            if line.find('<td align="center">')!=-1:
                ohcl=OHCL(self.isin,  self.xulpymoney).init__from_html_line(line, self.productype)
                if ohcl!=None:
                    self.arr.append(ohcl)

    def get_prices( self, from_date):

        class Render(QWebEngineView):
            def __init__(self, url, from_date):
                QWebEngineView.__init__(self)
                self.loop=QEventLoop()#Queda en un loop hasta que acaba la carga de todas las páginas
                self.loadFinished.connect(self._loadFinished)
                self.pages=[]
                self.from_date=from_date
                self.load(QUrl(url))
                self.loop.exec()

            def numPages(self):
                return len(self.pages)

            def _loadFinished(self, result):
                """
                   This is an async call, you need to wait for this to be called before closing the app
                """
                self.page().toHtml(self._callable)

            def _callable(self, data):
                """
                   Se llama cada vez que una página es cargada con el html en data
                """
                self.pages.append(data)
                time.sleep(0.125)

                if self.numPages()==1:
                    self.page().runJavaScript('''
                                                 var dDia = document.getElementsByName("ctl00$Contenido$Desde$Dia")[0]; dDia.value={};
                                                 var dMes = document.getElementsByName("ctl00$Contenido$Desde$Mes")[0]; dMes.value={};
                                                 var dAnio = document.getElementsByName("ctl00$Contenido$Desde$Año")[0]; dAnio.value={};
                                                 var Button = document.getElementsByName("ctl00$Contenido$Buscar")[0]; Button.click();
                                              '''.format(self.from_date.day,self.from_date.month,self.from_date.year))
                else:
                    if data.find("ctl00_Contenido_SiguientesAbj")!=-1:
                        self.page().runJavaScript('var link= document.getElementById("ctl00_Contenido_SiguientesAbj"); link.click();')
                    else:
                        self.loop.quit()#CUIDADO DEBE ESTAR EN EL ULTIMO
        ###########################
        if self.productype==eProductType.Share:
            r=Render("http://www.bolsamadrid.es/esp/aspx/Empresas/InfHistorica.aspx?ISIN={}".format(self.isin), from_date)
        elif self.productype==eProductType.ETF:
            r=Render("http://www.bolsamadrid.es/esp/aspx/ETFs/Mercados/InfHistorica.aspx?ISIN={}".format(self.isin), from_date)
        elif self.productype==eProductType.Index:
            r=Render("http://www.bolsamadrid.es/esp/aspx/Indices/InfHistorica.aspx?grupo=IBEX", from_date)
        for i,page in enumerate(r.pages):
            if i==0:#Era la de la búsqueda
                continue
            self.searchQuotesInHtml(page)

    def print(self):
        for ohcl in self.arr:
            print (ohcl)


class CurrentPrice:
    def __init__(self):
        self.isin=None
        self.xulpymoney=None 
        self.dtaware=None
        self.price=None

    def init__from_html_line_without_date(self,line,  productype, dtaware):
        """
        Returns None if fails    
        """
        self.dtaware=dtaware
        try:
            l=line.split("</td>")#Arr
            if productype==eProductType.PublicBond:
                self.isin=l[1][-12:]
                self.price=Decimal(l[4].split(">")[1].replace(",","."))
            return self
        except:
            print ("ERROR | CURRENT PRICE COULDN'T HAVE BEING  GENERATED | {}".format(line))
            return None
            
    def init__from_html_line_with_date(self, line):
        line=line.split("FichaValor.aspx?ISIN=")[1]#Removes begin
        line=line[:-5]#Removes end
        line=line.replace(' class="DifClIg"', "").replace(' class="DifClSb"', "").replace(' class="DifClBj"', "").replace(' align="center" colspan="2"', "").replace(' class="Ult" align="center"',"").replace(' align="center"',"")#Removes anomalies to live td /td
        a=line.split("</td><td>")
        self.isin=a[0][:12]
        self.price=a[1].replace(",", ".")
        if len(a)==9:#Ignoring suspendido
            if a[8]=="Cierre":
                hour="17:38"
            else:
                hour=a[8]
            self.dtaware=string2datetime("{} {}".format(a[7], hour), type=3, zone="Europe/Madrid")
            return self
        return None

    def __repr__(self):
        if self.xulpymoney!=None:
            return "PRICE | XULPYMONEY | {} | {} | {}".format(self.xulpymoney, self.dtaware, self.price)
        else:
            return "PRICE | STOCKMARKET | ES | ISIN | {} | {} | {}".format(self.isin, self.dtaware , self.price)

class SetCurrentPrice:
    def __init__(self, arrIsin, arrXulpymoney,  productype):
        """
           arrIsin is a list of isin of the same productype
        """
        self.arrIsin=arrIsin
        self.arrXulpymoney=arrXulpymoney
        self.arr=[]
        self.productype=productype

    def searchQuotesInHtml(self,html):
        """Looks for quotes line in html and creates all current prices in the pages"""
        if self.productype==eProductType.PublicBond:
            for line in html.split("\n"):#Extracts datetime
                if line.find("sh_titulo")!=-1:
                    dt_aware=string2datetime(line.split(">")[1].split("<")[0], type=3,  zone="Europe/Madrid")
                    break
            for line in html.split("\n"):
                if line.find('000.000')!=-1:
                    cp=CurrentPrice().init__from_html_line_without_date(line, self.productype,dt_aware)
                    if cp!=None:
                        self.arr.append(cp)
                        
        elif self.productype in [eProductType.Share, eProductType.ETF]:
            for line in html.split("\n"):
                if line.find("FichaValor")!=-1:
                    cp=CurrentPrice().init__from_html_line_with_date(line)
                    if cp!=None:
                        self.arr.append(cp)

    def get_prices( self):
        class RenderCurrentPrice(QWebEngineView):
            def __init__(self, url, productype):
                QWebEngineView.__init__(self)
                self.loop=QEventLoop()#Queda en un loop hasta que acaba la carga de todas las páginas
                self.loadFinished.connect(self._loadFinished)
                self.pages=[]
                self.productype=productype
                self.page().profile().cookieStore().deleteAllCookies()
                self.page().profile().setPersistentCookiesPolicy(QWebEngineProfile.NoPersistentCookies)
                
                self.load(QUrl(url))
                self.loop.exec()

            def numPages(self):
                return len(self.pages)

            def _loadFinished(self, result):
                self.page().toHtml(self._callable)

            def _callable(self, data):
                self.pages.append(data)
                time.sleep(0.25)
                if self.productype==eProductType.PublicBond:
                    if self.numPages()==1:
                        self.page().runJavaScript('''window.location.href="/esp/aspx/aiaf/Precios.aspx?menu=47"''')
                    elif self.numPages()==2:
                        self.page().runJavaScript('''window.location.href="/esp/aspx/send/posicionesDPublica_v2.aspx"''')
                    elif self.numPages()==3:
                        self.loop.quit()#CUIDADO DEBE ESTAR EN EL ULTIMO
                elif self.productype==eProductType.Share:
                    if self.numPages()==1:
                        self.page().runJavaScript('''
                                                var select= document.getElementsByName("ctl00$Contenido$SelMercado")[0]; select.value="MC";
                                                var Button = document.getElementsByName("ctl00$Contenido$Consultar")[0]; Button.click();''')
                    elif self.numPages()==2:
                        self.page().runJavaScript('''__doPostBack("ctl00$Contenido$Todos","");''')
                    elif self.numPages()==3:
                        self.loop.quit()#CUIDADO DEBE ESTAR EN EL ULTIMO
                elif self.productype==eProductType.ETF:
                    if self.numPages()==1:
                        self.page().runJavaScript('''
                                                var select= document.getElementsByName("ctl00$Contenido$SelMercado")[0]; select.value="ETF";
                                                var Button = document.getElementsByName("ctl00$Contenido$Consultar")[0]; Button.click();''')
                    elif self.numPages()==2:
                        self.loop.quit()#CUIDADO DEBE ESTAR EN EL ULTIMO
        ###########################
        if self.productype==eProductType.PublicBond:
            r=RenderCurrentPrice("http://www.bmerf.es", self.productype)
        elif self.productype in [eProductType.Share,  eProductType.ETF]:
            r=RenderCurrentPrice("http://www.bolsamadrid.es/esp/aspx/Mercados/Precios.aspx?indice=ESI100000000", self.productype)
            
        for i,page in enumerate(r.pages):
#            print ("Page", i+1, len(r.pages[i]))
            if self.productype in [eProductType.Share, eProductType.PublicBond]:
                if i<2:#Era la de la búsqueda
                    continue
            elif self.productype==eProductType.ETF:
                if i<1:
                    continue
            self.searchQuotesInHtml(page)

    def returnDesired(self):
        """
           Returns desired Quotes
        """
        desired=[]
        for i, isin in enumerate(self.arrIsin):
            for cp in self.arr:
                 if cp.isin==isin:
                     if self.arrXulpymoney!=None:
                        cp.xulpymoney=self.arrXulpymoney[i]
                     desired.append(cp)
        return desired

    def print(self):
        for cp in self.arr:
            print (cp)

def main():
    global app
    app = QApplication(sys.argv)
    parser=argparse.ArgumentParser("xulpymoney_sync_quotes")
    group1=parser.add_mutually_exclusive_group(required=True)
    group1.add_argument('--ISIN', help='ISIN code',action="append", metavar="X")
    group1.add_argument('--ISIN_XULPYMONEY', help='Pass ISIN and XULPYMONEY code',action="append", nargs=2, metavar="X")
    parser.add_argument('--fromdate', help='Get historcal prices from date in YYYY-MM-DD format. Without this parameter it gets current price')
    group2=parser.add_mutually_exclusive_group(required=True)
    group2.add_argument('--share', help="Share search", action='store_true', default=False)
    group2.add_argument('--index', help="Index search", action='store_true', default=False) 
    group2.add_argument('--etf', help="ETF search", action='store_true', default=False) 
    group2.add_argument('--publicbond', help="Public bond search", action='store_true', default=False) 
    args=parser.parse_args()

    #Array ISIN and XULPYMONEY. If no xulpymoney it creates a list of None values
    ISIN=[]
    XULPYMONEY=[]
    if args.ISIN:
        for isin in args.ISIN:
            ISIN.append(isin)
            XULPYMONEY.append(None)
    else:#ISIN_XULPYMONEY
        for isin, xulpymoney in args.ISIN_XULPYMONEY:
            ISIN.append(isin)
            XULPYMONEY.append(xulpymoney)

    if len(ISIN)>1 and args.fromdate:
        print("ERROR | TOO MANY ISIN CODES | {}".format(sys.argv))
        sys.exit(0)

    if args.fromdate:
        try:
            fromdate=string2date(args.fromdate)
        except:
            print("ERROR | FROM DATE CONVERSION ERROR | {}".format(args.fromdate))
            sys.exit(0)

        if args.share==True:
            s=SetOHCL(ISIN[0], XULPYMONEY[0], eProductType.Share)
            s.get_prices(fromdate)
            s.print()

        if args.etf==True:
            s=SetOHCL(ISIN[0], XULPYMONEY[0], eProductType.ETF)
            s.get_prices(fromdate)
            s.print()

        if args.index==True:
            s=SetOHCL(ISIN[0], XULPYMONEY[0], eProductType.Index)
            s.get_prices(fromdate)
            s.print()
    else:
        if args.publicbond==True:
            s=SetCurrentPrice(ISIN, XULPYMONEY, eProductType.PublicBond)
            s.get_prices()
            for pc in s.returnDesired():
                print (pc)

        if args.share==True:
            s=SetCurrentPrice(ISIN, XULPYMONEY, eProductType.Share)
            s.get_prices()
            for pc in s.returnDesired():
                print (pc)
        if args.etf==True:
            s=SetCurrentPrice(ISIN, XULPYMONEY, eProductType.ETF)
            s.get_prices()
            for pc in s.returnDesired():
                print (pc)




from PyQt5.QtCore import pyqtSlot
from PyQt5.QtWidgets import QDialog
from xulpymoney.ui.Ui_frmSharesTransfer import Ui_frmSharesTransfer
from xulpymoney.libxulpymoneyfunctions import qmessagebox
from decimal import Decimal

class frmSharesTransfer(QDialog, Ui_frmSharesTransfer):
    def __init__(self, mem, origen,   parent=None):
        QDialog.__init__(self, parent)
        self.setupUi(self)
        self.mem=mem
        self.origen=origen#Clase inversión
        self.lbl.setText(self.tr("Shares transfer from\n{0}").format(self.origen.name))
        self.txtAcciones.setText(str(self.origen.shares()))
        self.mem.data.investments_active().qcombobox_same_investmentmq(self.combo, self.origen.product)

    @pyqtSlot()  
    def on_buttons_accepted(self):
        destino=self.mem.data.investments_active().find_by_id(self.combo.itemData(self.combo.currentIndex()))
        if self.origen==destino:
            qmessagebox(self.tr("Origin and destiny transfer can't be the same"))
            return
            
        if self.txtComision.decimal()<Decimal('0'):
            qmessagebox(self.tr("Comission must be a positive amount"))
            return            
            
        if self.mem.data.investments_active().traspaso_valores(self.origen, destino, self.txtAcciones.decimal(), self.txtComision.decimal())==False: 
            qmessagebox(self.tr("The shares transfer couldn't be done"))
        self.accept()
        

    @pyqtSlot()  
    def on_buttons_rejected(self):
        self.reject()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/frmSplitManual.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_frmSplitManual(object):
    def setupUi(self, frmSplitManual):
        frmSplitManual.setObjectName("frmSplitManual")
        frmSplitManual.resize(872, 477)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/study.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        frmSplitManual.setWindowIcon(icon)
        frmSplitManual.setSizeGripEnabled(True)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(frmSplitManual)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label = QtWidgets.QLabel(frmSplitManual)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.verticalLayout_3.addWidget(self.label)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.wdgDtStart = wdgDatetime(frmSplitManual)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.wdgDtStart.sizePolicy().hasHeightForWidth())
        self.wdgDtStart.setSizePolicy(sizePolicy)
        self.wdgDtStart.setObjectName("wdgDtStart")
        self.horizontalLayout_3.addWidget(self.wdgDtStart)
        self.line = QtWidgets.QFrame(frmSplitManual)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_3.addWidget(self.line)
        self.wdgDtEnd = wdgDatetime(frmSplitManual)
        self.wdgDtEnd.setObjectName("wdgDtEnd")
        self.horizontalLayout_3.addWidget(self.wdgDtEnd)
        self.verticalLayout_3.addLayout(self.horizontalLayout_3)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_2 = QtWidgets.QLabel(frmSplitManual)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setItalic(True)
        self.label_2.setFont(font)
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.verticalLayout.addWidget(self.label_2)
        self.txtInitial = myQLineEdit(frmSplitManual)
        self.txtInitial.setAlignment(QtCore.Qt.AlignCenter)
        self.txtInitial.setObjectName("txtInitial")
        self.verticalLayout.addWidget(self.txtInitial)
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_3 = QtWidgets.QLabel(frmSplitManual)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setItalic(True)
        self.label_3.setFont(font)
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_2.addWidget(self.label_3)
        self.txtFinal = myQLineEdit(frmSplitManual)
        self.txtFinal.setAlignment(QtCore.Qt.AlignCenter)
        self.txtFinal.setObjectName("txtFinal")
        self.verticalLayout_2.addWidget(self.txtFinal)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.lblExample = QtWidgets.QLabel(frmSplitManual)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.lblExample.setFont(font)
        self.lblExample.setAlignment(QtCore.Qt.AlignCenter)
        self.lblExample.setWordWrap(True)
        self.lblExample.setObjectName("lblExample")
        self.verticalLayout_3.addWidget(self.lblExample)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem2)
        self.buttonbox = QtWidgets.QDialogButtonBox(frmSplitManual)
        self.buttonbox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonbox.setCenterButtons(True)
        self.buttonbox.setObjectName("buttonbox")
        self.horizontalLayout_2.addWidget(self.buttonbox)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem3)
        self.verticalLayout_3.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_4.addLayout(self.verticalLayout_3)

        self.retranslateUi(frmSplitManual)
        QtCore.QMetaObject.connectSlotsByName(frmSplitManual)

    def retranslateUi(self, frmSplitManual):
        _translate = QtCore.QCoreApplication.translate
        frmSplitManual.setWindowTitle(_translate("frmSplitManual", "Split / Contrasplit relation"))
        self.label.setText(_translate("frmSplitManual", "Manual Split / Contrasplit to adjust split directly on prices (Not recomended)"))
        self.label_2.setText(_translate("frmSplitManual", "Current Shares"))
        self.txtInitial.setText(_translate("frmSplitManual", "1"))
        self.label_3.setText(_translate("frmSplitManual", "Final Shares"))
        self.txtFinal.setText(_translate("frmSplitManual", "10"))


from xulpymoney.ui.myqlineedit import myQLineEdit
from xulpymoney.ui.wdgDatetime import wdgDatetime
import xulpymoney.images.xulpymoney_rc



from PyQt5.QtCore import pyqtSlot
from PyQt5.QtWidgets import QDialog, QMenu, QTableWidgetItem,  QInputDialog
from xulpymoney.libxulpymoney import Concept
from xulpymoney.libxulpymoneyfunctions import qmessagebox
from xulpymoney.ui.Ui_frmAuxiliarTables import Ui_frmAuxiliarTables

class frmAuxiliarTables(QDialog, Ui_frmAuxiliarTables):
    def __init__(self, mem,  parent = None, name = None, modal = False):
        """
        Constructor
        
        @param parent The parent widget of this dialog. (QWidget)
        @param name The name of this dialog. (QString)
        @param modal Flag indicating a modal dialog. (boolean)
        """
        QDialog.__init__(self,  parent)
        if name:
            self.setObjectName(name)
        self.setModal(True)
        self.setupUi(self)
        self.mem=mem

        self.tblConcepts.settings(self.mem, "frmAuxiliarTables")
        self.concepts=None
        self.regenerate_list()
        self.tblConcepts_reload()
    
    def regenerate_list(self):
        self.concepts=self.mem.conceptos.clone_editables()

    @pyqtSlot()  
    def on_actionChangeName_triggered(self):
        t=QInputDialog().getText(self,  "Xulpymoney",  self.tr("Change name"))
        if t[1]==True:
            self.concepts.selected.name=t[0]
            self.concepts.selected.save()
            self.mem.con.commit()
            self.mem.conceptos.order_by_name()
            self.regenerate_list()
            self.tblConcepts_reload()

    @pyqtSlot()  
    def on_actionExpensesAdd_triggered(self):
        t=QInputDialog().getText(self,  "Xulpymoney",  self.tr("Add a new expense concept"))
        if t[1]==True:
            concepto=Concept(self.mem, t[0], self.mem.tiposoperaciones.find_by_id(1), True, None)
            concepto.save()
            self.mem.con.commit()
            self.mem.conceptos.append(concepto)
            self.mem.conceptos.order_by_name()
            self.regenerate_list()
            self.tblConcepts_reload()

    @pyqtSlot()  
    def on_actionIncomesAdd_triggered(self):
        t=QInputDialog().getText(self,  "Xulpymoney",  self.tr("Add a new income concept"))
        if t[1]==True:
            concepto=Concept(self.mem, t[0], self.mem.tiposoperaciones.find_by_id(2), True, None)
            concepto.save()
            self.mem.con.commit()
            self.mem.conceptos.append(concepto)
            self.mem.conceptos.order_by_name()
            self.regenerate_list()
            self.tblConcepts_reload()

    @pyqtSlot()  
    def on_actionConceptDelete_triggered(self):
        if self.concepts.selected.borrar():
            self.mem.con.commit()
            self.mem.conceptos.remove(self.concepts.selected)
            self.regenerate_list()
            self.tblConcepts.clearSelection()
            self.concepts.selected=None
            self.tblConcepts_reload()
        else:
            qmessagebox(self.tr("This concept can't be deleted"))

    def on_tblConcepts_customContextMenuRequested(self,  pos):
        if self.concepts.selected==None:
            self.actionChangeName.setEnabled(False)
            self.actionConceptDelete.setEnabled(False)
        else:
            self.actionChangeName.setEnabled(True)
            self.actionConceptDelete.setEnabled(True)
        
        menu=QMenu()
        menu.addAction(self.actionExpensesAdd)
        menu.addAction(self.actionIncomesAdd)
        menu.addAction(self.actionChangeName)
        menu.addAction(self.actionConceptDelete)
        menu.exec_(self.tblConcepts.mapToGlobal(pos))

    def on_tblConcepts_itemSelectionChanged(self):
        try:
            for i in self.tblConcepts.selectedItems():#itera por cada item no row.
                self.concepts.selected=self.concepts.arr[i.row()]
        except:
            self.concepts.selected=None        

    def tblConcepts_reload(self):
        self.tblConcepts.setRowCount(self.concepts.length())
        self.tblConcepts.applySettings()
        for i, c in enumerate(self.concepts.arr):
            self.tblConcepts.setItem(i, 0, QTableWidgetItem(c.name))
            self.tblConcepts.setItem(i, 1, QTableWidgetItem(c.tipooperacion.name))



import argparse
import multiprocessing
from subprocess import  check_output,    DEVNULL
from concurrent.futures import ProcessPoolExecutor,  as_completed
from multiprocessing import cpu_count

from xulpymoney.libxulpymoneyfunctions import  dirs_create, b2s
from xulpymoney.libcounter import Counter

def appendSource(arr, name):
    counter=Counter(len(arr))
    counter.setName(name)
    sourceoutput=[]
    commands=[]
    for c in arr:
        try:
            output=check_output(c,  shell=True,  timeout=30, stderr=DEVNULL)
            commands.append(c)
            sourceoutput.append(output)
            counter.next_step()
        except:
            sourceoutput.append(b"ERROR | appendSource\n")
    return commands, sourceoutput

def appendSourceWithConcurrence(arr, name,  num_workers):
    def call_back(para):
        counter.next_step()
        
    counter=Counter(len(arr))
    counter.setName(name)
    sourceoutput=[]
    commands=[]
    futures=[]
    with ProcessPoolExecutor(max_workers=num_workers) as executor:
        for   a in arr: 
            try:
                future=executor.submit(check_output,  a,  timeout=30,  shell=True, stderr=DEVNULL)
                future.add_done_callback(call_back)
                futures.append([a, future])
            except:
                pass
        
        as_completed([f[1] for f in futures])#Extrae lista de futures
        for command,  future in futures:
            commands.append(command)
            try:
                sourceoutput.append(future.result())
            except:
                sourceoutput.append(b"ERROR | appendSourceWithConcurrence\n")
    return commands, sourceoutput
    ###################################################################

def main():
    parser=argparse.ArgumentParser("xulpymoney_sync_quotes")
    parser.add_argument('--filename', help='Filename',action="store", metavar="X", default=None)
    args=parser.parse_args()

    dir_tmp=dirs_create()
    arrBolsaMadrid=[]
    arrMorningStar=[]
    arrQueFondos=[]
    arrGoogle=[]
    arrYahoo=[]
    arrInfobolsa=[]
    global lock
    lock=multiprocessing.Lock()
    if args.filename==None:
        filename="{}/clients.txt".format(dir_tmp)
        output="{}/clients_result.txt".format(dir_tmp)
    else:
        filename=args.filename
        output= "{}.clients_result.txt".format(filename)
    f=open(filename, "r")
    for line in f.readlines():
        line=line[:-1]
        if line.find("bolsamadrid")!=-1:
            arrBolsaMadrid.append(line)
        if line.find("morningstar")!=-1:
            arrMorningStar.append(line)
        if line.find("quefondos")!=-1:
            arrQueFondos.append(line)
        if line.find("google")!=-1:
            arrGoogle.append(line)
        if line.find("yahoo")!=-1:
            arrYahoo.append(line)
        if line.find("infobolsa")!=-1:
            arrYahoo.append(line)
    f.close()

    futures=[]
    with ProcessPoolExecutor(max_workers=cpu_count()+1) as executor:
            futures.append(executor.submit(appendSource, arrBolsaMadrid, "xulpymoney_bolsamadrid_client"))
            futures.append(executor.submit(appendSourceWithConcurrence, arrMorningStar, "xulpymoney_morningstar_client", cpu_count()+1))
            futures.append(executor.submit(appendSourceWithConcurrence, arrQueFondos, "xulpymoney_quefondos_client", cpu_count()+1))
            futures.append(executor.submit(appendSourceWithConcurrence, arrGoogle, "xulpymoney_google_client",cpu_count()+1))
            futures.append(executor.submit(appendSourceWithConcurrence, arrYahoo, "xulpymoney_yahoo_client", cpu_count()+1))
            futures.append(executor.submit(appendSourceWithConcurrence, arrInfobolsa, "xulpymoney_infobolsa_client", cpu_count()+1))

    f=open(output, "w")
    for fut in as_completed(futures):
        commands, out=fut.result()
        for i, c in enumerate(commands):
            f.write("{}\n".format(commands[i]))
            for o in b2s(out[i]).split("\n"):
                if o=="":
                    f.write("\n")
                else:
                    f.write("  + {}\n".format(o))
    f.close()




from PyQt5.QtCore import pyqtSlot
from PyQt5.QtWidgets import QDialog
from xulpymoney.libxulpymoneyfunctions import b2c, c2b
from xulpymoney.libxulpymoneytypes import eProductType
from decimal import Decimal
from xulpymoney.ui.Ui_frmSettings import Ui_frmSettings

class frmSettings(QDialog, Ui_frmSettings):
    def __init__(self, mem, parent = None, name = None, modal = False):
        """
        Constructor

        @param parent The parent widget of this dialog. (QWidget)
        @param name The name of this dialog. (QString)
        @param modal Flag indicating a modal dialog. (boolean)
        """
        QDialog.__init__(self, parent)
        if name:
            self.setObjectName(name)
        self.setModal(True)
        self.setupUi(self)
        self.mem=mem
 
        self.mem.currencies.qcombobox(self.cmbCurrencies,self.mem.localcurrency)
        self.mem.languages.qcombobox(self.cmbLanguages,self.mem.language)
        self.mem.zones.qcombobox(self.cmbZones, self.mem.localzone)
        self.indexes=self.mem.data.products.ProductManager_with_same_type(self.mem.types.find_by_id(eProductType.Index.value))
        self.indexes.order_by_name()
        self.indexes.qcombobox(self.cmbIndex, self.mem.data.benchmark)
        self.spnDividendPercentage.setValue(float(self.mem.dividendwithholding)*100)
        self.spnGainsPercentaje.setValue(float(self.mem.taxcapitalappreciation)*100)
        self.spnGainsPercentajeBelow.setValue(float(self.mem.taxcapitalappreciationbelow)*100)
        self.chkGainsYear.setChecked(b2c(self.mem.gainsyear))
        if self.mem.gainsyear==False:
            self.spnGainsPercentajeBelow.setEnabled(False)

    @pyqtSlot(str)      
    def on_cmbLanguages_currentIndexChanged(self, stri):
        self.mem.language=self.mem.languages.find_by_id(self.cmbLanguages.itemData(self.cmbLanguages.currentIndex()))
        self.mem.settings.setValue("mem/language", self.mem.language.id)
        self.mem.languages.cambiar(self.mem.language.id)
        self.retranslateUi(self)

    @pyqtSlot()
    def on_buttonbox_accepted(self):
        self.mem.localcurrency=self.mem.currencies.find_by_id(self.cmbCurrencies.itemData(self.cmbCurrencies.currentIndex()))
        self.mem.localzone=self.mem.zones.find_by_id(self.cmbZones.itemData(self.cmbZones.currentIndex()))
        self.mem.data.benchmark=self.mem.data.products.find_by_id(self.cmbIndex.itemData(self.cmbIndex.currentIndex()))
        self.mem.data.benchmark.needStatus(2)
        self.mem.dividendwithholding=Decimal(self.spnDividendPercentage.value())/100
        self.mem.taxcapitalappreciation=Decimal(self.spnGainsPercentaje.value())/100
        self.mem.taxcapitalappreciationbelow=Decimal(self.spnGainsPercentajeBelow.value())/100
        self.mem.gainsyear=c2b(self.chkGainsYear.checkState())
        self.mem.save_MemSettingsDB()
        
        self.mem.languages.cambiar(self.cmbLanguages.itemData(self.cmbLanguages.currentIndex()))       
        self.retranslateUi(self)
        
        self.accept()    
        
    def on_chkGainsYear_stateChanged(self, state):
        self.spnGainsPercentajeBelow.setEnabled(c2b(state))
        
    @pyqtSlot()
    def on_buttonbox_rejected(self):
        self.reject()
        



## @namespace xulpymoney.xulpymoney
## @brief Main Xulpymoney script.

import sys
import argparse
import logging
import signal
from colorama import init, Style, Fore

from PyQt5.QtCore import QTranslator
from PyQt5.QtWidgets import QApplication,  QDialog
import xulpymoney.libdbupdates
from xulpymoney.libxulpymoney import MemXulpymoney
from xulpymoney.version import  __versiondate__
from xulpymoney.libxulpymoneyfunctions import addDebugSystem, addCommonToArgParse
from xulpymoney.ui.frmAccess import frmAccess
from xulpymoney.ui.frmMain import frmMain

def signal_handler(signal, frame):
        logging.critical(Style.BRIGHT+Fore.RED+app.translate("Core","You pressed 'Ctrl+C', exiting..."))
        sys.exit(1)

######################

def main():
    from PyQt5 import QtWebEngineWidgets # To avoid error must be imported before QCoreApplication
    dir(QtWebEngineWidgets)
    init(autoreset=True)

    global app
    app = QApplication(sys.argv)
    app.setOrganizationName("Mariano Muñoz ©")
    app.setOrganizationDomain("turulomio.users.sourceforge.net")
    app.setApplicationName("Xulpymoney")

    signal.signal(signal.SIGINT, signal_handler)

    parser=argparse.ArgumentParser(
            prog='xulpymoney', 
            description=app.translate("Core",'Personal accounting system'),  
            epilog=app.translate("Core","If you like this app, please vote for it in Sourceforge (https://sourceforge.net/projects/xulpymoney/reviews/).")+"\n" +app.translate("Core","Developed by Mariano Muñoz 2015-{}".format(__versiondate__.year)),
            formatter_class=argparse.RawTextHelpFormatter
        )
    addCommonToArgParse(parser)
    args=parser.parse_args()        

    addDebugSystem(args)

    mem=MemXulpymoney()
    mem.setQTranslator(QTranslator(app))
    mem.languages.cambiar(mem.language.id)

    access=frmAccess(mem)
    access.setLabel(QApplication.translate("Core","Please login to the xulpymoney database"))
    access.config_load()
    access.exec_()

    if access.result()==QDialog.Accepted:
        mem.con=access.con

        xulpymoney.libdbupdates.Update(mem)##Update database

        mem.frmMain = frmMain(mem)
        mem.frmMain.show()
        sys.exit(app.exec_())

if __name__=="__main__":
        main()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/frmMain.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_frmMain(object):
    def setupUi(self, frmMain):
        frmMain.setObjectName("frmMain")
        frmMain.resize(1458, 625)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(frmMain.sizePolicy().hasHeightForWidth())
        frmMain.setSizePolicy(sizePolicy)
        frmMain.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/coins.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        frmMain.setWindowIcon(icon)
        self.central = QtWidgets.QWidget(frmMain)
        self.central.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.central.sizePolicy().hasHeightForWidth())
        self.central.setSizePolicy(sizePolicy)
        self.central.setObjectName("central")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.central)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.layout = QtWidgets.QVBoxLayout()
        self.layout.setObjectName("layout")
        self.horizontalLayout.addLayout(self.layout)
        frmMain.setCentralWidget(self.central)
        self.menuBar = QtWidgets.QMenuBar(frmMain)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 1458, 34))
        self.menuBar.setObjectName("menuBar")
        self.menuAyuda = QtWidgets.QMenu(self.menuBar)
        self.menuAyuda.setObjectName("menuAyuda")
        self.menuBancos = QtWidgets.QMenu(self.menuBar)
        self.menuBancos.setObjectName("menuBancos")
        self.menuInformes = QtWidgets.QMenu(self.menuBar)
        self.menuInformes.setObjectName("menuInformes")
        self.menuCuentas = QtWidgets.QMenu(self.menuBar)
        self.menuCuentas.setObjectName("menuCuentas")
        self.menuInversiones = QtWidgets.QMenu(self.menuBar)
        self.menuInversiones.setObjectName("menuInversiones")
        self.menuXulpymoney = QtWidgets.QMenu(self.menuBar)
        self.menuXulpymoney.setObjectName("menuXulpymoney")
        self.menuProducts = QtWidgets.QMenu(self.menuBar)
        self.menuProducts.setObjectName("menuProducts")
        self.menuIndexes = QtWidgets.QMenu(self.menuProducts)
        self.menuIndexes.setObjectName("menuIndexes")
        self.menuMaintenance = QtWidgets.QMenu(self.menuProducts)
        self.menuMaintenance.setObjectName("menuMaintenance")
        self.menuReports = QtWidgets.QMenu(self.menuProducts)
        self.menuReports.setObjectName("menuReports")
        self.menuShares = QtWidgets.QMenu(self.menuProducts)
        self.menuShares.setObjectName("menuShares")
        self.menuCurrencies = QtWidgets.QMenu(self.menuProducts)
        self.menuCurrencies.setObjectName("menuCurrencies")
        self.menuBonds = QtWidgets.QMenu(self.menuProducts)
        self.menuBonds.setObjectName("menuBonds")
        self.menuFunds = QtWidgets.QMenu(self.menuProducts)
        self.menuFunds.setObjectName("menuFunds")
        self.menuETF = QtWidgets.QMenu(self.menuProducts)
        self.menuETF.setObjectName("menuETF")
        self.menuWarrants = QtWidgets.QMenu(self.menuProducts)
        self.menuWarrants.setObjectName("menuWarrants")
        frmMain.setMenuBar(self.menuBar)
        self.tbMain = QtWidgets.QToolBar(frmMain)
        self.tbMain.setIconSize(QtCore.QSize(26, 26))
        self.tbMain.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.tbMain.setObjectName("tbMain")
        frmMain.addToolBar(QtCore.Qt.TopToolBarArea, self.tbMain)
        self.statusBar = QtWidgets.QStatusBar(frmMain)
        self.statusBar.setObjectName("statusBar")
        frmMain.setStatusBar(self.statusBar)
        self.tbProducts = QtWidgets.QToolBar(frmMain)
        self.tbProducts.setIconSize(QtCore.QSize(26, 26))
        self.tbProducts.setObjectName("tbProducts")
        frmMain.addToolBar(QtCore.Qt.TopToolBarArea, self.tbProducts)
        self.tbSettings = QtWidgets.QToolBar(frmMain)
        self.tbSettings.setObjectName("tbSettings")
        frmMain.addToolBar(QtCore.Qt.TopToolBarArea, self.tbSettings)
        self.actionExit = QtWidgets.QAction(frmMain)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/exit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionExit.setIcon(icon1)
        self.actionExit.setObjectName("actionExit")
        self.actionAbout = QtWidgets.QAction(frmMain)
        self.actionAbout.setIcon(icon)
        self.actionAbout.setObjectName("actionAbout")
        self.actionIndexRange = QtWidgets.QAction(frmMain)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/xulpymoney/layers.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionIndexRange.setIcon(icon2)
        self.actionIndexRange.setObjectName("actionIndexRange")
        self.actionInvestments = QtWidgets.QAction(frmMain)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/xulpymoney/investment.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionInvestments.setIcon(icon3)
        self.actionInvestments.setObjectName("actionInvestments")
        self.actionAuxiliarTables = QtWidgets.QAction(frmMain)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/xulpymoney/table.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAuxiliarTables.setIcon(icon4)
        self.actionAuxiliarTables.setObjectName("actionAuxiliarTables")
        self.actionDividendsReport = QtWidgets.QAction(frmMain)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/xulpymoney/dividends.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDividendsReport.setIcon(icon5)
        self.actionDividendsReport.setObjectName("actionDividendsReport")
        self.actionEvolutionReport = QtWidgets.QAction(frmMain)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/xulpymoney/dinero.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionEvolutionReport.setIcon(icon6)
        self.actionEvolutionReport.setObjectName("actionEvolutionReport")
        self.actionTotalReport = QtWidgets.QAction(frmMain)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/xulpymoney/totalreport.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionTotalReport.setIcon(icon7)
        self.actionTotalReport.setObjectName("actionTotalReport")
        self.actionAccounts = QtWidgets.QAction(frmMain)
        self.actionAccounts.setIcon(icon)
        self.actionAccounts.setObjectName("actionAccounts")
        self.actionBanks = QtWidgets.QAction(frmMain)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/xulpymoney/bank.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionBanks.setIcon(icon8)
        self.actionBanks.setObjectName("actionBanks")
        self.actionInvestmentsClasses = QtWidgets.QAction(frmMain)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/xulpymoney/pie.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionInvestmentsClasses.setIcon(icon9)
        self.actionInvestmentsClasses.setObjectName("actionInvestmentsClasses")
        self.actionTransfer = QtWidgets.QAction(frmMain)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/xulpymoney/transfer.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionTransfer.setIcon(icon10)
        self.actionTransfer.setObjectName("actionTransfer")
        self.actionConcepts = QtWidgets.QAction(frmMain)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/xulpymoney/hucha.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionConcepts.setIcon(icon11)
        self.actionConcepts.setObjectName("actionConcepts")
        self.actionMemory = QtWidgets.QAction(frmMain)
        self.actionMemory.setIcon(icon10)
        self.actionMemory.setObjectName("actionMemory")
        self.actionSettings = QtWidgets.QAction(frmMain)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/xulpymoney/configure.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSettings.setIcon(icon12)
        self.actionSettings.setObjectName("actionSettings")
        self.actionHelp = QtWidgets.QAction(frmMain)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/xulpymoney/books.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionHelp.setIcon(icon13)
        self.actionHelp.setObjectName("actionHelp")
        self.actionInvestmentsOperations = QtWidgets.QAction(frmMain)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/xulpymoney/document-edit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionInvestmentsOperations.setIcon(icon14)
        self.actionInvestmentsOperations.setObjectName("actionInvestmentsOperations")
        self.actionCalculator = QtWidgets.QAction(frmMain)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/xulpymoney/kcalc.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCalculator.setIcon(icon15)
        self.actionCalculator.setObjectName("actionCalculator")
        self.actionSearch = QtWidgets.QAction(frmMain)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/xulpymoney/search.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSearch.setIcon(icon16)
        self.actionSearch.setObjectName("actionSearch")
        self.actionIndexesAll = QtWidgets.QAction(frmMain)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/xulpymoney/kmplot.jpg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionIndexesAll.setIcon(icon17)
        self.actionIndexesAll.setObjectName("actionIndexesAll")
        self.actionIbex35 = QtWidgets.QAction(frmMain)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/countries/spain.gif"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionIbex35.setIcon(icon18)
        self.actionIbex35.setObjectName("actionIbex35")
        self.actionEurostoxx50 = QtWidgets.QAction(frmMain)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(":/countries/eu.gif"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionEurostoxx50.setIcon(icon19)
        self.actionEurostoxx50.setObjectName("actionEurostoxx50")
        self.actionSP500 = QtWidgets.QAction(frmMain)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(":/countries/usa.gif"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSP500.setIcon(icon20)
        self.actionSP500.setObjectName("actionSP500")
        self.actionCAC40 = QtWidgets.QAction(frmMain)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(":/countries/france.gif"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCAC40.setIcon(icon21)
        self.actionCAC40.setObjectName("actionCAC40")
        self.actionNasdaq100 = QtWidgets.QAction(frmMain)
        self.actionNasdaq100.setIcon(icon20)
        self.actionNasdaq100.setObjectName("actionNasdaq100")
        self.actionMC = QtWidgets.QAction(frmMain)
        self.actionMC.setIcon(icon18)
        self.actionMC.setObjectName("actionMC")
        self.actionXetra = QtWidgets.QAction(frmMain)
        icon22 = QtGui.QIcon()
        icon22.addPixmap(QtGui.QPixmap(":/countries/germany.gif"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionXetra.setIcon(icon22)
        self.actionXetra.setObjectName("actionXetra")
        self.actionProductsAutoUpdate = QtWidgets.QAction(frmMain)
        self.actionProductsAutoUpdate.setIcon(icon10)
        self.actionProductsAutoUpdate.setObjectName("actionProductsAutoUpdate")
        self.actionProductsObsolete = QtWidgets.QAction(frmMain)
        icon23 = QtGui.QIcon()
        icon23.addPixmap(QtGui.QPixmap(":/xulpymoney/checkbox0.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductsObsolete.setIcon(icon23)
        self.actionProductsObsolete.setObjectName("actionProductsObsolete")
        self.actionProductsUser = QtWidgets.QAction(frmMain)
        icon24 = QtGui.QIcon()
        icon24.addPixmap(QtGui.QPixmap(":/xulpymoney/keko.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductsUser.setIcon(icon24)
        self.actionProductsUser.setObjectName("actionProductsUser")
        self.actionCurrenciesAll = QtWidgets.QAction(frmMain)
        icon25 = QtGui.QIcon()
        icon25.addPixmap(QtGui.QPixmap(":/xulpymoney/Money.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCurrenciesAll.setIcon(icon25)
        self.actionCurrenciesAll.setObjectName("actionCurrenciesAll")
        self.actionFavorites = QtWidgets.QAction(frmMain)
        icon26 = QtGui.QIcon()
        icon26.addPixmap(QtGui.QPixmap(":/xulpymoney/star.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFavorites.setIcon(icon26)
        self.actionFavorites.setObjectName("actionFavorites")
        self.actionProductsNotAutoUpdate = QtWidgets.QAction(frmMain)
        icon27 = QtGui.QIcon()
        icon27.addPixmap(QtGui.QPixmap(":/xulpymoney/editar.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductsNotAutoUpdate.setIcon(icon27)
        self.actionProductsNotAutoUpdate.setObjectName("actionProductsNotAutoUpdate")
        self.actionDividends = QtWidgets.QAction(frmMain)
        icon28 = QtGui.QIcon()
        icon28.addPixmap(QtGui.QPixmap(":/xulpymoney/dividends_biggest.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDividends.setIcon(icon28)
        self.actionDividends.setObjectName("actionDividends")
        self.actionWarrantsCall = QtWidgets.QAction(frmMain)
        self.actionWarrantsCall.setIcon(icon)
        self.actionWarrantsCall.setObjectName("actionWarrantsCall")
        self.actionWarrantsPut = QtWidgets.QAction(frmMain)
        self.actionWarrantsPut.setIcon(icon)
        self.actionWarrantsPut.setObjectName("actionWarrantsPut")
        self.actionWarrantsInline = QtWidgets.QAction(frmMain)
        self.actionWarrantsInline.setIcon(icon)
        self.actionWarrantsInline.setObjectName("actionWarrantsInline")
        self.actionBondsAll = QtWidgets.QAction(frmMain)
        icon29 = QtGui.QIcon()
        icon29.addPixmap(QtGui.QPixmap(":/xulpymoney/history2.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionBondsAll.setIcon(icon29)
        self.actionBondsAll.setObjectName("actionBondsAll")
        self.actionSharesAll = QtWidgets.QAction(frmMain)
        self.actionSharesAll.setIcon(icon17)
        self.actionSharesAll.setObjectName("actionSharesAll")
        self.actionBondsPublic = QtWidgets.QAction(frmMain)
        self.actionBondsPublic.setIcon(icon29)
        self.actionBondsPublic.setObjectName("actionBondsPublic")
        self.actionBondsPrivate = QtWidgets.QAction(frmMain)
        self.actionBondsPrivate.setIcon(icon29)
        self.actionBondsPrivate.setObjectName("actionBondsPrivate")
        self.actionWarrantsAll = QtWidgets.QAction(frmMain)
        self.actionWarrantsAll.setIcon(icon)
        self.actionWarrantsAll.setObjectName("actionWarrantsAll")
        self.actionISINDuplicado = QtWidgets.QAction(frmMain)
        icon30 = QtGui.QIcon()
        icon30.addPixmap(QtGui.QPixmap(":/xulpymoney/document-preview-archive.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionISINDuplicado.setIcon(icon30)
        self.actionISINDuplicado.setObjectName("actionISINDuplicado")
        self.actionPurgeAll = QtWidgets.QAction(frmMain)
        icon31 = QtGui.QIcon()
        icon31.addPixmap(QtGui.QPixmap(":/xulpymoney/tools-wizard.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPurgeAll.setIcon(icon31)
        self.actionPurgeAll.setObjectName("actionPurgeAll")
        self.actionProductsWithoutISIN = QtWidgets.QAction(frmMain)
        icon32 = QtGui.QIcon()
        icon32.addPixmap(QtGui.QPixmap(":/xulpymoney/gafas.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductsWithoutISIN.setIcon(icon32)
        self.actionProductsWithoutISIN.setObjectName("actionProductsWithoutISIN")
        self.actionETFAll = QtWidgets.QAction(frmMain)
        icon33 = QtGui.QIcon()
        icon33.addPixmap(QtGui.QPixmap(":/images/kmplot.jpg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionETFAll.setIcon(icon33)
        self.actionETFAll.setObjectName("actionETFAll")
        self.actionFundsAll = QtWidgets.QAction(frmMain)
        icon34 = QtGui.QIcon()
        icon34.addPixmap(QtGui.QPixmap(":/images/document-preview.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFundsAll.setIcon(icon34)
        self.actionFundsAll.setObjectName("actionFundsAll")
        self.actionPriceUpdates = QtWidgets.QAction(frmMain)
        self.actionPriceUpdates.setIcon(icon10)
        self.actionPriceUpdates.setObjectName("actionPriceUpdates")
        self.actionProductsInvestmentActive = QtWidgets.QAction(frmMain)
        self.actionProductsInvestmentActive.setIcon(icon13)
        self.actionProductsInvestmentActive.setObjectName("actionProductsInvestmentActive")
        self.actionProductsInvestmentInactive = QtWidgets.QAction(frmMain)
        self.actionProductsInvestmentInactive.setIcon(icon13)
        self.actionProductsInvestmentInactive.setObjectName("actionProductsInvestmentInactive")
        self.actionIndexesObsolete = QtWidgets.QAction(frmMain)
        self.actionIndexesObsolete.setIcon(icon23)
        self.actionIndexesObsolete.setObjectName("actionIndexesObsolete")
        self.actionSharesObsolete = QtWidgets.QAction(frmMain)
        self.actionSharesObsolete.setIcon(icon23)
        self.actionSharesObsolete.setObjectName("actionSharesObsolete")
        self.actionETFObsolete = QtWidgets.QAction(frmMain)
        self.actionETFObsolete.setIcon(icon23)
        self.actionETFObsolete.setObjectName("actionETFObsolete")
        self.actionWarrantsObsolete = QtWidgets.QAction(frmMain)
        self.actionWarrantsObsolete.setIcon(icon23)
        self.actionWarrantsObsolete.setObjectName("actionWarrantsObsolete")
        self.actionFundsObsolete = QtWidgets.QAction(frmMain)
        self.actionFundsObsolete.setIcon(icon23)
        self.actionFundsObsolete.setObjectName("actionFundsObsolete")
        self.actionBondsObsolete = QtWidgets.QAction(frmMain)
        self.actionBondsObsolete.setIcon(icon23)
        self.actionBondsObsolete.setObjectName("actionBondsObsolete")
        self.actionGlobalReport = QtWidgets.QAction(frmMain)
        icon35 = QtGui.QIcon()
        icon35.addPixmap(QtGui.QPixmap(":/xulpymoney/new.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionGlobalReport.setIcon(icon35)
        self.actionGlobalReport.setObjectName("actionGlobalReport")
        self.actionSyncProducts = QtWidgets.QAction(frmMain)
        icon36 = QtGui.QIcon()
        icon36.addPixmap(QtGui.QPixmap(":/xulpymoney/database.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSyncProducts.setIcon(icon36)
        self.actionSyncProducts.setObjectName("actionSyncProducts")
        self.actionSimulations = QtWidgets.QAction(frmMain)
        icon37 = QtGui.QIcon()
        icon37.addPixmap(QtGui.QPixmap(":/xulpymoney/replication.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSimulations.setIcon(icon37)
        self.actionSimulations.setObjectName("actionSimulations")
        self.actionLastOperation = QtWidgets.QAction(frmMain)
        self.actionLastOperation.setIcon(icon30)
        self.actionLastOperation.setObjectName("actionLastOperation")
        self.actionOrders = QtWidgets.QAction(frmMain)
        icon38 = QtGui.QIcon()
        icon38.addPixmap(QtGui.QPixmap(":/xulpymoney/order.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOrders.setIcon(icon38)
        self.actionOrders.setObjectName("actionOrders")
        self.actionCuriosities = QtWidgets.QAction(frmMain)
        icon39 = QtGui.QIcon()
        icon39.addPixmap(QtGui.QPixmap(":/xulpymoney/curiosity.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCuriosities.setIcon(icon39)
        self.actionCuriosities.setObjectName("actionCuriosities")
        self.actionInvestmentRanking = QtWidgets.QAction(frmMain)
        icon40 = QtGui.QIcon()
        icon40.addPixmap(QtGui.QPixmap(":/xulpymoney/crown.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionInvestmentRanking.setIcon(icon40)
        self.actionInvestmentRanking.setObjectName("actionInvestmentRanking")
        self.actionProductsWithoutQuotes = QtWidgets.QAction(frmMain)
        icon41 = QtGui.QIcon()
        icon41.addPixmap(QtGui.QPixmap(":/xulpymoney/alarm_clock.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductsWithoutQuotes.setIcon(icon41)
        self.actionProductsWithoutQuotes.setObjectName("actionProductsWithoutQuotes")
        self.actionProductsWithOldPrice = QtWidgets.QAction(frmMain)
        icon42 = QtGui.QIcon()
        icon42.addPixmap(QtGui.QPixmap(":/xulpymoney/expired.jpg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductsWithOldPrice.setIcon(icon42)
        self.actionProductsWithOldPrice.setObjectName("actionProductsWithOldPrice")
        self.actionProductsWithPriceVariation = QtWidgets.QAction(frmMain)
        self.actionProductsWithPriceVariation.setIcon(icon41)
        self.actionProductsWithPriceVariation.setObjectName("actionProductsWithPriceVariation")
        self.actionPurchaseOpportunities = QtWidgets.QAction(frmMain)
        icon43 = QtGui.QIcon()
        icon43.addPixmap(QtGui.QPixmap(":/xulpymoney/opportunity.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPurchaseOpportunities.setIcon(icon43)
        self.actionPurchaseOpportunities.setObjectName("actionPurchaseOpportunities")
        self.actionProductsUpdate = QtWidgets.QAction(frmMain)
        icon44 = QtGui.QIcon()
        icon44.addPixmap(QtGui.QPixmap(":/xulpymoney/cloud_download.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductsUpdate.setIcon(icon44)
        self.actionProductsUpdate.setObjectName("actionProductsUpdate")
        self.actionProductsInvalidISIN = QtWidgets.QAction(frmMain)
        icon45 = QtGui.QIcon()
        icon45.addPixmap(QtGui.QPixmap(":/xulpymoney/dialog-ok-apply.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductsInvalidISIN.setIcon(icon45)
        self.actionProductsInvalidISIN.setObjectName("actionProductsInvalidISIN")
        self.actionProductsComparation = QtWidgets.QAction(frmMain)
        icon46 = QtGui.QIcon()
        icon46.addPixmap(QtGui.QPixmap(":/xulpymoney/compare.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductsComparation.setIcon(icon46)
        self.actionProductsComparation.setObjectName("actionProductsComparation")
        self.actionShowBenchmark = QtWidgets.QAction(frmMain)
        icon47 = QtGui.QIcon()
        icon47.addPixmap(QtGui.QPixmap(":/xulpymoney/benchmark.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionShowBenchmark.setIcon(icon47)
        self.actionShowBenchmark.setObjectName("actionShowBenchmark")
        self.actionInvestmentsZeroRisk = QtWidgets.QAction(frmMain)
        icon48 = QtGui.QIcon()
        icon48.addPixmap(QtGui.QPixmap(":/xulpymoney/zerorisk.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionInvestmentsZeroRisk.setIcon(icon48)
        self.actionInvestmentsZeroRisk.setObjectName("actionInvestmentsZeroRisk")
        self.menuAyuda.addAction(self.actionAbout)
        self.menuAyuda.addSeparator()
        self.menuAyuda.addAction(self.actionCuriosities)
        self.menuAyuda.addSeparator()
        self.menuAyuda.addAction(self.actionHelp)
        self.menuBancos.addAction(self.actionBanks)
        self.menuInformes.addAction(self.actionPurchaseOpportunities)
        self.menuInformes.addSeparator()
        self.menuInformes.addAction(self.actionConcepts)
        self.menuInformes.addAction(self.actionDividendsReport)
        self.menuInformes.addAction(self.actionEvolutionReport)
        self.menuInformes.addAction(self.actionIndexRange)
        self.menuInformes.addAction(self.actionTotalReport)
        self.menuInformes.addSeparator()
        self.menuInformes.addAction(self.actionGlobalReport)
        self.menuCuentas.addAction(self.actionAccounts)
        self.menuCuentas.addSeparator()
        self.menuCuentas.addAction(self.actionTransfer)
        self.menuInversiones.addAction(self.actionInvestments)
        self.menuInversiones.addAction(self.actionInvestmentsZeroRisk)
        self.menuInversiones.addSeparator()
        self.menuInversiones.addAction(self.actionOrders)
        self.menuInversiones.addAction(self.actionPurchaseOpportunities)
        self.menuInversiones.addSeparator()
        self.menuInversiones.addAction(self.actionInvestmentsClasses)
        self.menuInversiones.addSeparator()
        self.menuInversiones.addAction(self.actionLastOperation)
        self.menuInversiones.addAction(self.actionInvestmentsOperations)
        self.menuInversiones.addSeparator()
        self.menuInversiones.addAction(self.actionCalculator)
        self.menuInversiones.addSeparator()
        self.menuInversiones.addAction(self.actionInvestmentRanking)
        self.menuXulpymoney.addAction(self.actionMemory)
        self.menuXulpymoney.addSeparator()
        self.menuXulpymoney.addAction(self.actionAuxiliarTables)
        self.menuXulpymoney.addSeparator()
        self.menuXulpymoney.addAction(self.actionSettings)
        self.menuXulpymoney.addSeparator()
        self.menuXulpymoney.addAction(self.actionSimulations)
        self.menuXulpymoney.addSeparator()
        self.menuXulpymoney.addAction(self.actionExit)
        self.menuIndexes.addAction(self.actionEurostoxx50)
        self.menuIndexes.addAction(self.actionIbex35)
        self.menuIndexes.addAction(self.actionMC)
        self.menuIndexes.addAction(self.actionSP500)
        self.menuIndexes.addAction(self.actionCAC40)
        self.menuIndexes.addAction(self.actionNasdaq100)
        self.menuIndexes.addAction(self.actionXetra)
        self.menuIndexes.addSeparator()
        self.menuIndexes.addAction(self.actionIndexesAll)
        self.menuIndexes.addSeparator()
        self.menuIndexes.addAction(self.actionIndexesObsolete)
        self.menuMaintenance.addSeparator()
        self.menuMaintenance.addAction(self.actionPurgeAll)
        self.menuReports.addAction(self.actionDividends)
        self.menuReports.addSeparator()
        self.menuReports.addAction(self.actionProductsWithoutQuotes)
        self.menuReports.addAction(self.actionProductsWithOldPrice)
        self.menuReports.addSeparator()
        self.menuReports.addAction(self.actionProductsWithPriceVariation)
        self.menuReports.addSeparator()
        self.menuReports.addAction(self.actionProductsAutoUpdate)
        self.menuReports.addAction(self.actionProductsNotAutoUpdate)
        self.menuReports.addSeparator()
        self.menuReports.addAction(self.actionProductsInvestmentActive)
        self.menuReports.addAction(self.actionProductsInvestmentInactive)
        self.menuReports.addSeparator()
        self.menuReports.addAction(self.actionProductsUser)
        self.menuReports.addAction(self.actionProductsObsolete)
        self.menuReports.addSeparator()
        self.menuReports.addAction(self.actionProductsWithoutISIN)
        self.menuReports.addAction(self.actionISINDuplicado)
        self.menuReports.addAction(self.actionProductsInvalidISIN)
        self.menuShares.addAction(self.actionSharesAll)
        self.menuShares.addSeparator()
        self.menuShares.addAction(self.actionSharesObsolete)
        self.menuCurrencies.addAction(self.actionCurrenciesAll)
        self.menuBonds.addAction(self.actionBondsPrivate)
        self.menuBonds.addAction(self.actionBondsPublic)
        self.menuBonds.addAction(self.actionBondsAll)
        self.menuBonds.addSeparator()
        self.menuBonds.addAction(self.actionBondsObsolete)
        self.menuFunds.addAction(self.actionFundsAll)
        self.menuFunds.addSeparator()
        self.menuFunds.addAction(self.actionFundsObsolete)
        self.menuETF.addAction(self.actionETFAll)
        self.menuETF.addSeparator()
        self.menuETF.addAction(self.actionETFObsolete)
        self.menuWarrants.addAction(self.actionWarrantsInline)
        self.menuWarrants.addAction(self.actionWarrantsPut)
        self.menuWarrants.addAction(self.actionWarrantsCall)
        self.menuWarrants.addSeparator()
        self.menuWarrants.addAction(self.actionWarrantsAll)
        self.menuWarrants.addSeparator()
        self.menuWarrants.addAction(self.actionWarrantsObsolete)
        self.menuProducts.addAction(self.actionProductsUpdate)
        self.menuProducts.addSeparator()
        self.menuProducts.addAction(self.actionShowBenchmark)
        self.menuProducts.addSeparator()
        self.menuProducts.addAction(self.menuIndexes.menuAction())
        self.menuProducts.addAction(self.menuShares.menuAction())
        self.menuProducts.addAction(self.menuETF.menuAction())
        self.menuProducts.addAction(self.menuWarrants.menuAction())
        self.menuProducts.addAction(self.menuFunds.menuAction())
        self.menuProducts.addAction(self.menuBonds.menuAction())
        self.menuProducts.addAction(self.menuCurrencies.menuAction())
        self.menuProducts.addSeparator()
        self.menuProducts.addAction(self.menuReports.menuAction())
        self.menuProducts.addSeparator()
        self.menuProducts.addAction(self.menuMaintenance.menuAction())
        self.menuProducts.addSeparator()
        self.menuProducts.addAction(self.actionProductsComparation)
        self.menuProducts.addAction(self.actionFavorites)
        self.menuProducts.addAction(self.actionSearch)
        self.menuProducts.addSeparator()
        self.menuProducts.addAction(self.actionPriceUpdates)
        self.menuProducts.addSeparator()
        self.menuProducts.addAction(self.actionSyncProducts)
        self.menuBar.addAction(self.menuXulpymoney.menuAction())
        self.menuBar.addAction(self.menuBancos.menuAction())
        self.menuBar.addAction(self.menuCuentas.menuAction())
        self.menuBar.addAction(self.menuInversiones.menuAction())
        self.menuBar.addAction(self.menuInformes.menuAction())
        self.menuBar.addAction(self.menuProducts.menuAction())
        self.menuBar.addAction(self.menuAyuda.menuAction())
        self.tbMain.addAction(self.actionBanks)
        self.tbMain.addAction(self.actionAccounts)
        self.tbMain.addAction(self.actionInvestments)
        self.tbMain.addSeparator()
        self.tbMain.addAction(self.actionOrders)
        self.tbMain.addAction(self.actionPurchaseOpportunities)
        self.tbMain.addSeparator()
        self.tbMain.addAction(self.actionIndexRange)
        self.tbMain.addAction(self.actionLastOperation)
        self.tbMain.addAction(self.actionConcepts)
        self.tbMain.addAction(self.actionDividendsReport)
        self.tbMain.addAction(self.actionInvestmentsClasses)
        self.tbMain.addAction(self.actionTotalReport)
        self.tbMain.addAction(self.actionInvestmentRanking)
        self.tbMain.addSeparator()
        self.tbMain.addAction(self.actionCalculator)
        self.tbProducts.addAction(self.actionShowBenchmark)
        self.tbProducts.addAction(self.actionFavorites)
        self.tbProducts.addAction(self.actionIndexesAll)
        self.tbProducts.addAction(self.actionSearch)
        self.tbProducts.addSeparator()
        self.tbProducts.addAction(self.actionProductsComparation)
        self.tbProducts.addSeparator()
        self.tbProducts.addAction(self.actionPriceUpdates)
        self.tbProducts.addAction(self.actionSyncProducts)
        self.tbSettings.addAction(self.actionProductsUpdate)
        self.tbSettings.addAction(self.actionSettings)
        self.tbSettings.addAction(self.actionExit)

        self.retranslateUi(frmMain)
        QtCore.QMetaObject.connectSlotsByName(frmMain)

    def retranslateUi(self, frmMain):
        _translate = QtCore.QCoreApplication.translate
        self.menuAyuda.setTitle(_translate("frmMain", "He&lp"))
        self.menuBancos.setTitle(_translate("frmMain", "&Banks"))
        self.menuInformes.setTitle(_translate("frmMain", "&Reports"))
        self.menuCuentas.setTitle(_translate("frmMain", "A&ccounts"))
        self.menuInversiones.setTitle(_translate("frmMain", "&Investments"))
        self.menuXulpymoney.setTitle(_translate("frmMain", "&Xulpymoney"))
        self.menuProducts.setTitle(_translate("frmMain", "Prod&ucts"))
        self.menuIndexes.setTitle(_translate("frmMain", "&Indexes"))
        self.menuMaintenance.setTitle(_translate("frmMain", "&Maintenance"))
        self.menuReports.setTitle(_translate("frmMain", "&Reports"))
        self.menuShares.setTitle(_translate("frmMain", "&Shares"))
        self.menuCurrencies.setTitle(_translate("frmMain", "&Currencies"))
        self.menuBonds.setTitle(_translate("frmMain", "&Bonds"))
        self.menuFunds.setTitle(_translate("frmMain", "&Funds"))
        self.menuETF.setTitle(_translate("frmMain", "&ETF"))
        self.menuWarrants.setTitle(_translate("frmMain", "&Warrants"))
        self.tbMain.setWindowTitle(_translate("frmMain", "Main toolbar"))
        self.tbProducts.setWindowTitle(_translate("frmMain", "Products toolbar"))
        self.tbSettings.setWindowTitle(_translate("frmMain", "Settings toolbar"))
        self.actionExit.setText(_translate("frmMain", "E&xit"))
        self.actionExit.setToolTip(_translate("frmMain", "Exit"))
        self.actionExit.setShortcut(_translate("frmMain", "Alt+Esc"))
        self.actionAbout.setText(_translate("frmMain", "&About"))
        self.actionAbout.setToolTip(_translate("frmMain", "About"))
        self.actionAbout.setShortcut(_translate("frmMain", "F2"))
        self.actionIndexRange.setText(_translate("frmMain", "&Index range"))
        self.actionIndexRange.setToolTip(_translate("frmMain", "Index range"))
        self.actionInvestments.setText(_translate("frmMain", "&Investments"))
        self.actionInvestments.setToolTip(_translate("frmMain", "Investments"))
        self.actionAuxiliarTables.setText(_translate("frmMain", "&Auxiliar tables"))
        self.actionAuxiliarTables.setToolTip(_translate("frmMain", "Auxiliar tables"))
        self.actionDividendsReport.setText(_translate("frmMain", "&Dividends report"))
        self.actionEvolutionReport.setText(_translate("frmMain", "&Evolution report"))
        self.actionEvolutionReport.setToolTip(_translate("frmMain", "Evolution report"))
        self.actionTotalReport.setText(_translate("frmMain", "&Total report"))
        self.actionTotalReport.setToolTip(_translate("frmMain", "Total report"))
        self.actionTotalReport.setShortcut(_translate("frmMain", "F10"))
        self.actionAccounts.setText(_translate("frmMain", "&Accounts"))
        self.actionAccounts.setToolTip(_translate("frmMain", "Accounts"))
        self.actionBanks.setText(_translate("frmMain", "&Banks"))
        self.actionBanks.setToolTip(_translate("frmMain", "Banks"))
        self.actionInvestmentsClasses.setText(_translate("frmMain", "Investment types &report"))
        self.actionTransfer.setText(_translate("frmMain", "&Transfer"))
        self.actionTransfer.setToolTip(_translate("frmMain", "Transfer"))
        self.actionConcepts.setText(_translate("frmMain", "&Concepts"))
        self.actionConcepts.setToolTip(_translate("frmMain", "Concepts"))
        self.actionMemory.setText(_translate("frmMain", "&Update memory"))
        self.actionMemory.setToolTip(_translate("frmMain", "Update memory"))
        self.actionSettings.setText(_translate("frmMain", "&Settings"))
        self.actionSettings.setToolTip(_translate("frmMain", "Settings"))
        self.actionHelp.setText(_translate("frmMain", "&Help"))
        self.actionHelp.setToolTip(_translate("frmMain", "Help"))
        self.actionHelp.setShortcut(_translate("frmMain", "F1"))
        self.actionInvestmentsOperations.setText(_translate("frmMain", "I&nvestment operations list"))
        self.actionInvestmentsOperations.setToolTip(_translate("frmMain", "Investment operations list"))
        self.actionCalculator.setText(_translate("frmMain", "&Order calculator"))
        self.actionCalculator.setToolTip(_translate("frmMain", "Order calculator"))
        self.actionSearch.setText(_translate("frmMain", "Search"))
        self.actionSearch.setShortcut(_translate("frmMain", "Ctrl+B"))
        self.actionIndexesAll.setText(_translate("frmMain", "&All Indexes"))
        self.actionIndexesAll.setShortcut(_translate("frmMain", "Ctrl+I"))
        self.actionIbex35.setText(_translate("frmMain", "&Ibex 35"))
        self.actionEurostoxx50.setText(_translate("frmMain", "&Eurostoxx 50"))
        self.actionSP500.setText(_translate("frmMain", "&S&&P 500"))
        self.actionCAC40.setText(_translate("frmMain", "&CAC 40"))
        self.actionNasdaq100.setText(_translate("frmMain", "&Nasdaq 100"))
        self.actionMC.setText(_translate("frmMain", "&Mercado Continuo"))
        self.actionXetra.setText(_translate("frmMain", "&Xetra"))
        self.actionProductsAutoUpdate.setText(_translate("frmMain", "&Products with auto update"))
        self.actionProductsAutoUpdate.setToolTip(_translate("frmMain", "Products with auto update"))
        self.actionProductsObsolete.setText(_translate("frmMain", "&Obsolete products"))
        self.actionProductsObsolete.setToolTip(_translate("frmMain", "Obsolete products"))
        self.actionProductsUser.setText(_translate("frmMain", "&User products"))
        self.actionProductsUser.setToolTip(_translate("frmMain", "User products"))
        self.actionCurrenciesAll.setText(_translate("frmMain", "&All currencies"))
        self.actionCurrenciesAll.setToolTip(_translate("frmMain", "All currencies"))
        self.actionFavorites.setText(_translate("frmMain", "S&how favorites"))
        self.actionFavorites.setToolTip(_translate("frmMain", "Show favorites"))
        self.actionProductsNotAutoUpdate.setText(_translate("frmMain", "Products &without auto update"))
        self.actionProductsNotAutoUpdate.setToolTip(_translate("frmMain", "Products without auto update"))
        self.actionDividends.setText(_translate("frmMain", "&Biggest dividends"))
        self.actionDividends.setToolTip(_translate("frmMain", "Biggest dividends"))
        self.actionWarrantsCall.setText(_translate("frmMain", "All &call warrants"))
        self.actionWarrantsPut.setText(_translate("frmMain", "All &put warrants"))
        self.actionWarrantsInline.setText(_translate("frmMain", "&All inline warrants"))
        self.actionBondsAll.setText(_translate("frmMain", "All &bonds"))
        self.actionBondsAll.setToolTip(_translate("frmMain", "All bonds"))
        self.actionSharesAll.setText(_translate("frmMain", "&All shares"))
        self.actionSharesAll.setToolTip(_translate("frmMain", "All shares"))
        self.actionBondsPublic.setText(_translate("frmMain", "All &public bonds"))
        self.actionBondsPublic.setToolTip(_translate("frmMain", "All public bonds"))
        self.actionBondsPrivate.setText(_translate("frmMain", "&All private bonds"))
        self.actionBondsPrivate.setToolTip(_translate("frmMain", "All private bonds"))
        self.actionWarrantsAll.setText(_translate("frmMain", "All &warrants"))
        self.actionWarrantsAll.setToolTip(_translate("frmMain", "All warrants"))
        self.actionISINDuplicado.setText(_translate("frmMain", "&Duplicated ISIN products"))
        self.actionISINDuplicado.setToolTip(_translate("frmMain", "Duplicated ISIN products"))
        self.actionPurgeAll.setText(_translate("frmMain", "&Purge all investments"))
        self.actionPurgeAll.setToolTip(_translate("frmMain", "Purge all investments"))
        self.actionProductsWithoutISIN.setText(_translate("frmMain", "Produ&cts without ISIN"))
        self.actionProductsWithoutISIN.setToolTip(_translate("frmMain", "Products without ISIN"))
        self.actionETFAll.setText(_translate("frmMain", "&All ETF"))
        self.actionFundsAll.setText(_translate("frmMain", "&All funds"))
        self.actionPriceUpdates.setText(_translate("frmMain", "&Price updates"))
        self.actionPriceUpdates.setToolTip(_translate("frmMain", "Price updates"))
        self.actionPriceUpdates.setShortcut(_translate("frmMain", "F8"))
        self.actionProductsInvestmentActive.setText(_translate("frmMain", "P&roducts of active investment"))
        self.actionProductsInvestmentActive.setToolTip(_translate("frmMain", "Products of active investment"))
        self.actionProductsInvestmentInactive.setText(_translate("frmMain", "Products of &inactive investment"))
        self.actionProductsInvestmentInactive.setToolTip(_translate("frmMain", "Products of inactive investment"))
        self.actionIndexesObsolete.setText(_translate("frmMain", "&Obsolete Indexes"))
        self.actionIndexesObsolete.setToolTip(_translate("frmMain", "Obsolete Indexes"))
        self.actionSharesObsolete.setText(_translate("frmMain", "&Obsolete shares"))
        self.actionSharesObsolete.setToolTip(_translate("frmMain", "Obsolete shares"))
        self.actionETFObsolete.setText(_translate("frmMain", "&Obsolete ETFs"))
        self.actionETFObsolete.setToolTip(_translate("frmMain", "Obsolete ETFs"))
        self.actionWarrantsObsolete.setText(_translate("frmMain", "&Obsolete warrants"))
        self.actionWarrantsObsolete.setToolTip(_translate("frmMain", "Obsolete warrants"))
        self.actionFundsObsolete.setText(_translate("frmMain", "&Obsolete funds"))
        self.actionFundsObsolete.setToolTip(_translate("frmMain", "Obsolete funds"))
        self.actionBondsObsolete.setText(_translate("frmMain", "&Obsolete bonds"))
        self.actionBondsObsolete.setToolTip(_translate("frmMain", "Obsolete bonds"))
        self.actionGlobalReport.setText(_translate("frmMain", "&Generate global report"))
        self.actionGlobalReport.setToolTip(_translate("frmMain", "Generate global report"))
        self.actionSyncProducts.setText(_translate("frmMain", "Sync products from &other Xulpymoney"))
        self.actionSyncProducts.setToolTip(_translate("frmMain", "Move products information to another database"))
        self.actionSyncProducts.setShortcut(_translate("frmMain", "F9"))
        self.actionSimulations.setText(_translate("frmMain", "S&imulations"))
        self.actionSimulations.setToolTip(_translate("frmMain", "Simulations"))
        self.actionSimulations.setShortcut(_translate("frmMain", "Ctrl+S"))
        self.actionLastOperation.setText(_translate("frmMain", "&Last operation"))
        self.actionLastOperation.setToolTip(_translate("frmMain", "Last operation"))
        self.actionOrders.setText(_translate("frmMain", "&Market orders"))
        self.actionOrders.setToolTip(_translate("frmMain", "Market orders"))
        self.actionCuriosities.setText(_translate("frmMain", "&Curiosities"))
        self.actionCuriosities.setToolTip(_translate("frmMain", "Curiosities"))
        self.actionInvestmentRanking.setText(_translate("frmMain", "In&vestment ranking"))
        self.actionInvestmentRanking.setToolTip(_translate("frmMain", "Investment ranking"))
        self.actionProductsWithoutQuotes.setText(_translate("frmMain", "Product&s without price"))
        self.actionProductsWithoutQuotes.setToolTip(_translate("frmMain", "Products without price"))
        self.actionProductsWithOldPrice.setText(_translate("frmMain", "Products wit&h old price"))
        self.actionProductsWithOldPrice.setToolTip(_translate("frmMain", "Products with old price"))
        self.actionProductsWithPriceVariation.setText(_translate("frmMain", "Products with a price &variation"))
        self.actionProductsWithPriceVariation.setToolTip(_translate("frmMain", "Product&s with a price variation"))
        self.actionPurchaseOpportunities.setText(_translate("frmMain", "&Purchase opportunities"))
        self.actionPurchaseOpportunities.setToolTip(_translate("frmMain", "Purchase opportunities"))
        self.actionProductsUpdate.setText(_translate("frmMain", "Products &update from Internet"))
        self.actionProductsUpdate.setToolTip(_translate("frmMain", "Products update from Internet"))
        self.actionProductsInvalidISIN.setText(_translate("frmMain", "Products with i&nvalid ISIN"))
        self.actionProductsInvalidISIN.setToolTip(_translate("frmMain", "Products with invalid ISIN"))
        self.actionProductsComparation.setText(_translate("frmMain", "Pro&ducts comparation"))
        self.actionProductsComparation.setToolTip(_translate("frmMain", "Products comparation"))
        self.actionShowBenchmark.setText(_translate("frmMain", "Show benchmark index"))
        self.actionShowBenchmark.setToolTip(_translate("frmMain", "Show benchmark index"))
        self.actionInvestmentsZeroRisk.setText(_translate("frmMain", "Zero risk investment list"))
        self.actionInvestmentsZeroRisk.setToolTip(_translate("frmMain", "Zero risk investment list"))


import xulpymoney.images.xulpymoney_rc



from setuptools import setup, Command
import os
import platform
import shutil
import site
from concurrent.futures import ProcessPoolExecutor
from multiprocessing import cpu_count

class Doxygen(Command):
    description = "Create/update doxygen documentation in doc/html"
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        print("Creating Doxygen Documentation")
        os.system("""sed -i -e "41d" doc/Doxyfile""")#Delete line 41
        os.system("""sed -i -e "41iPROJECT_NUMBER         = {}" doc/Doxyfile""".format(__version__))#Insert line 41
        os.system("rm -Rf build")
        os.chdir("doc")
        os.system("doxygen Doxyfile")
        os.system("rsync -avzP -e 'ssh -l turulomio' html/ frs.sourceforge.net:/home/users/t/tu/turulomio/userweb/htdocs/doxygen/xulpymoney/ --delete-after")
        os.chdir("..")

class PyInstaller(Command):
    description = "We run pyinstaller in build to avoid doing a ./xulpymoney module imort. I had problems with i18n. Before running this command I must have done a install, removing old installations"
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        os.system("python setup.py uninstall")
        os.system("python setup.py install")
        f=open("build/run.py","w")
        f.write("import xulpymoney\n")
        f.write("xulpymoney.main()\n")
        f.close()
        os.chdir("build")
        os.system("""pyinstaller run.py -n xulpymoney-{} --onefile --windowed --icon ../xulpymoney/images/xulpymoney.ico --distpath ../dist""".format(__version__))

class Compile(Command):
    description = "Compile ui and images"
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        futures=[]
        with ProcessPoolExecutor(max_workers=cpu_count()+1) as executor:
            for filename in os.listdir("xulpymoney/ui/"):
                if filename.endswith(".ui"):
                    without_extension=filename[:-3]
                    futures.append(executor.submit(os.system, "pyuic5 xulpymoney/ui/{0}.ui -o xulpymoney/ui/Ui_{0}.py".format(without_extension)))
            futures.append(executor.submit(os.system, "pyrcc5 xulpymoney/images/xulpymoney.qrc -o xulpymoney/images/xulpymoney_rc.py"))
        # Overwriting xulpymoney_rc
        for filename in os.listdir("xulpymoney/ui/"):
             if filename.startswith("Ui_"):
                 os.system("sed -i -e 's/xulpymoney_rc/xulpymoney.images.xulpymoney_rc/' xulpymoney/ui/{}".format(filename))
                 os.system("sed -i -e 's/from canvaschart/from xulpymoney.ui.canvaschart/' xulpymoney/ui/{}".format(filename))
                 os.system("sed -i -e 's/from myqlineedit/from xulpymoney.ui.myqlineedit/' xulpymoney/ui/{}".format(filename))
                 os.system("sed -i -e 's/from myqtablewidget/from xulpymoney.ui.myqtablewidget/' xulpymoney/ui/{}".format(filename))
                 os.system("sed -i -e 's/from xulpymoney.ui.myqlineedit/from xulpymoney.ui.myqlineedit/' xulpymoney/ui/{}".format(filename))
                 os.system("sed -i -e 's/from wdgTwoCurrencyLineEdit/from xulpymoney.ui.wdgTwoCurrencyLineEdit/' xulpymoney/ui/{}".format(filename))
                 os.system("sed -i -e 's/from wdgCurrencyConversion/from xulpymoney.ui.wdgCurrencyConversion/' xulpymoney/ui/{}".format(filename))
                 os.system("sed -i -e 's/from wdgProductSelector/from xulpymoney.ui.wdgProductSelector/' xulpymoney/ui/{}".format(filename))
                 os.system("sed -i -e 's/from wdgDatetime/from xulpymoney.ui.wdgDatetime/' xulpymoney/ui/{}".format(filename))
                 os.system("sed -i -e 's/from wdgYear/from xulpymoney.ui.wdgYear/' xulpymoney/ui/{}".format(filename))

class Uninstall(Command):
    description = "Uninstall installed files with install"
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        if platform.system()=="Linux":
            os.system("rm -Rf {}/xulpymoney*".format(site.getsitepackages()[0]))
            os.system("rm /usr/bin/xulpymone*")
            os.system("rm /usr/share/pixmaps/xulpymoney.png")
            os.system("rm /usr/share/applications/xulpymoney.desktop")
        else:
            print(site.getsitepackages())
            for file in os.listdir(site.getsitepackages()[1]):#site packages
                path=site.getsitepackages()[1]+"\\"+ file
                if file.find("xulpymoney")!=-1:
                    shutil.rmtree(path)
                    print(path,  "Erased")
            for file in os.listdir(site.getsitepackages()[0]+"\\Scripts\\"):#Scripts
                path=site.getsitepackages()[0]+"\\scripts\\"+ file
                if file.find("xulpymoney")!=-1:
                    os.remove(path)
                    print(path,  "Erased")

class Procedure(Command):
    description = "Uninstall installed files with install"
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        print("""
Nueva versión:
  * Cambiar la versión y la fecha en version.py
  * Modificar el Changelog en README
  * python setup.py doc
  * linguist
  * python setup.py doc
  * python setup.py install
  * python setup.py doxygen
  * git commit -a -m 'xulpymoney-{}'
  * git push
  * Hacer un nuevo tag en GitHub
  * python setup.py sdist upload -r pypi
  * Crea un nuevo ebuild de Gentoo con la nueva versión
  * Subelo al repositorio del portage
  * Change to windows. Enter in an Administrator console.
  * Change to xulpymoney source directory and make git pull
  * python setup.py pyinstaller
  * Add file to github release
""".format(__version__))

class Doc(Command):
    description = "Update translation librarys and hardcoded strings"
    user_options = [
      # The format is (long option, short option, description).
      ( 'user', None, 'Database user'),
      ( 'db', None, 'Database name'),
      ( 'port', None, 'Database port'),
      ( 'server', None, 'Database server'),
  ]
    def initialize_options(self):
        self.user="postgres"
        self.db="xulpymoney"
        self.port="5432"
        self.server="127.0.0.1"

    def finalize_options(self):
        pass

    def run(self):
        from xulpymoney.connection_pg import Connection
        con=Connection()

        con.user=self.user
        con.server=self.server
        con.port=self.port
        con.db=self.db

        con.get_password("", "")
        con.connect()
        
        rows=con.cursor_rows("select * from conceptos where id_conceptos < 100 order by id_conceptos")
        f=open("xulpymoney/hardcoded_strings.py", "w")
        f.write("from PyQt5.QtCore import QCoreApplication\n")
        f.write("QCoreApplication.translate('Core','Personal Management')\n")
        f.write("QCoreApplication.translate('Core','Cash')\n")
        for row in rows:
            f.write("QCoreApplication.translate('Core', '{}')\n".format(row["concepto"]))
        f.close()
        print("Is connection active?",  con.is_active())

        os.system("pylupdate5 -noobsolete -verbose xulpymoney.pro")
        os.system("lrelease -qt5 xulpymoney.pro")
    ########################################################################

#Description
with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

#entry_points
entry_points={
        'console_scripts': [
            'xulpymoney_bolsamadrid_client=xulpymoney.sources.bolsamadrid_client:main',
            'xulpymoney_google_client=xulpymoney.sources.google_client:main',
            'xulpymoney_infobolsa_client=xulpymoney.sources.infobolsa_client:main',
            'xulpymoney_morningstar_client=xulpymoney.sources.morningstar_client:main',
            'xulpymoney_quefondos_client=xulpymoney.sources.quefondos_client:main',
            'xulpymoney_run_client=xulpymoney.sources.run_client:main',
            'xulpymoney_yahoo_client=xulpymoney.sources.yahoo_client:main',
            'xulpymoney_reports_smm=xulpymoney.reports.smm:main',
        ],
        'gui_scripts':  [
            'xulpymoney=xulpymoney.xulpymoney:main',
            'xulpymoney_init=xulpymoney.xulpymoney_init:main',
        ],
    }
if platform.system()=="Windows":
    entry_points['console_scripts'].append( 'xulpymoney_shortcuts=xulpymoney.shortcuts:create',)

#data_files
if platform.system()=="Linux":
    data_files=[
        ('/usr/share/pixmaps/', ['xulpymoney/images/xulpymoney.png']), 
        ('/usr/share/applications/', ['xulpymoney.desktop']), 
    ]
else:
    data_files=[]

#__version__
__version__= None
with open('xulpymoney/version.py', encoding='utf-8') as f:
    for line in f.readlines():
        if line.find("__version__ =")!=-1:
            __version__=line.split("'")[1]

setup(name='xulpymoney',
    version=__version__,
    description='Home and financial accounting system',
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=['Development Status :: 4 - Beta',
              'Intended Audience :: End Users/Desktop',
              'Topic :: Office/Business :: Financial :: Accounting',
              'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
              'Programming Language :: Python :: 3',
             ], 
    keywords='financial home accounting system',
    url='https://github.com/Turulomio/xulpymoney',
    author='Turulomio',
    author_email='turulomio@yahoo.es',
    license='GPL-3',
    packages=['xulpymoney'],
    entry_points = entry_points, 
    install_requires= [ 'setuptools',
                        'psycopg2', 
                        'pytz',
                        'officegenerator', 
                        'colorama', 
                        'python-stdnum',
                        'PyQtChart;platform_system=="Windows"',
                        'PyQtWebEngine;platform_system=="Windows"',
                        'PyQt5;platform_system=="Windows"',
                        'pywin32;platform_system=="Windows"',
                        ], #PyQt5 and PyQtChart doesn't have egg-info in Gentoo, so I remove it to install it with ebuild without making 2 installations. Should be added manually when using pip to install
    data_files=data_files,
    cmdclass={
                        'doxygen': Doxygen,
                        'doc': Doc,
                        'uninstall':Uninstall, 
                        'compile': Compile, 
                        'procedure': Procedure,
                        'pyinstaller': PyInstaller,
                     }, 
    test_suite = 'xulpymoney.test',
    zip_safe=False,
    include_package_data=True
    )




from PyQt5.QtCore import  Qt,  pyqtSlot,  QObject
from PyQt5.QtGui import QPainter, QFont,  QColor
from xulpymoney.libxulpymoney import    Percentage
from xulpymoney.libxulpymoneyfunctions import epochms2dtaware, dtaware2epochms
from xulpymoney.libxulpymoneytypes import  eOHCLDuration
import datetime
from PyQt5.QtChart import QChart,  QLineSeries, QChartView, QValueAxis, QDateTimeAxis,  QPieSeries, QCandlestickSeries,  QCandlestickSet,  QScatterSeries

class VCTemporalSeries(QChartView):
    def __init__(self):
        QChartView.__init__(self)
        self.chart=QChart()
        self._allowHideSeries=True
        self.chart.setAnimationOptions(QChart.AllAnimations);
        self.chart.layout().setContentsMargins(0,0,0,0);

        #Axis cration
        self.axisX=QDateTimeAxis()
        self.axisX.setTickCount(15);
        self.axisX.setFormat("yyyy-MM");
        self.maxx=None
        self.maxy=None
        self.minx=None
        self.miny=None
        
        self.axisY = QValueAxis()
        self.axisY.setLabelFormat("%i")

        self.setRenderHint(QPainter.Antialiasing);
        
        self.series=[]
        self.__ohclduration=eOHCLDuration.Day

    def setAxisFormat(self, axis,  min, max, type, zone=None):
        """
            type=0 #Value
            type=1 # Datetime
            
            if zone=None remains in UTC, zone is a zone object.
        """
        if type==0:
            if max-min<=0.01:
                axis.setLabelFormat("%.4f")
            elif max-min<=100:
                axis.setLabelFormat("%.2f")
            else:
                axis.setLabelFormat("%i")
        elif type==1:
            max=epochms2dtaware(max)#UTC aware
            min=epochms2dtaware(min)
            if max-min<datetime.timedelta(days=1):
                axis.setFormat("hh:mm")
            else:
                axis.setFormat("yyyy-MM-dd")

    def setOHCLDuration(self, ohclduration):
        self.__ohclduration=ohclduration


    def setAllowHideSeries(self, boolean):
        self._allowHideSeries=boolean

        
    def appendTemporalSeries(self, name,  currency=None):
        """
            currency is a Currency object
        """
        self.currency=currency
        ls=QLineSeries()
        ls.setName(name)
        self.series.append(ls)
        return ls        

    def appendTemporalSeriesData(self, ls, x, y):
        """
            x is a datetime zone aware
        """
        x=dtaware2epochms(x)
        ls.append(x, y)
        
        if self.maxy==None:#Gives first maxy and miny
            self.maxy=y
            self.miny=y
            self.maxx=x
            self.minx=x
            
        if y>self.maxy:
            self.maxy=y
        if y<self.miny:
            self.miny=y
        if x>self.maxx:
            self.maxx=x
        if x<self.minx:
            self.minx=x
        
    def appendCandlestickSeries(self, name, currency):
        self.currency=currency
        ls=QCandlestickSeries()
        ls.setName(name)
        ls.setIncreasingColor(QColor(Qt.green));
        ls.setDecreasingColor(QColor(Qt.red));
        self.series.append(ls)
        return ls
        
    def appendCandlestickSeriesData(self, ls, ohcl):
        x=dtaware2epochms(ohcl.datetime())
        ls.append(QCandlestickSet(ohcl.open, ohcl.high, ohcl.low, ohcl.close, x ))
        if self.maxy==None:
            self.maxy=ohcl.high
            self.miny=ohcl.low
            self.maxx=x
            self.minx=x
        if ohcl.high>self.maxy:
            self.maxy=ohcl.high
        if ohcl.low<self.miny:
            self.miny=ohcl.low     
        if x>self.maxx:
            self.maxx=x
        if x<self.minx:
            self.minx=x
            
    def appendScatterSeries(self, name,  currency=None):
        """
            currency is a Currency object
        """
        self.currency=currency
        ls=QScatterSeries()
        ls.setName(name)
        self.series.append(ls)
        return ls

    def appendScatterSeriesData(self, ls, x, y):
        self.appendTemporalSeriesData(ls, x, y)
        
    def mouseMoveEvent(self, event):
        """
            event is a QMouseEvent
        """
        pass

    @pyqtSlot()
    def on_marker_clicked(self):
        marker=QObject.sender(self)#Busca el objeto que ha hecho la signal en el slot en el que está conectado, ya que estaban conectados varios objetos a una misma señal
        marker.series().setVisible(not marker.series().isVisible())
        marker.setVisible(True)
        if marker.series().isVisible():
            alpha = 1
        else:
            alpha=0.5

        lbrush=marker.labelBrush()
        color=lbrush.color()
        color.setAlphaF(alpha)
        lbrush.setColor(color)
        marker.setLabelBrush(lbrush)

        brush=marker.brush()
        color=brush.color()
        color.setAlphaF(alpha)
        brush.setColor(color)
        marker.setBrush(brush)
        
        pen=marker.pen()
        color=pen.color()
        color.setAlphaF(alpha)
        pen.setColor(color)
        marker.setPen(pen)
        
        
    def save(self, savefile):
        """
            Save view to a file to generate an image file
        """
        pixmap=self.grab()
        pixmap.save(savefile, quality=100)

    def display(self):
        self.setChart(self.chart)
        self.setAxisFormat(self.axisX, self.minx, self.maxx, 1)
        self.setAxisFormat(self.axisY, self.miny, self.maxy, 0)
        self.chart.addAxis(self.axisY, Qt.AlignLeft);
        self.chart.addAxis(self.axisX, Qt.AlignBottom);

        for s in self.series:
            self.chart.addSeries(s)
            s.attachAxis(self.axisX)
            s.attachAxis(self.axisY)
        self.axisY.setRange(self.miny, self.maxy)
        
        
        #Legend positions
        if len(self.chart.legend().markers())>6:
            self.chart.legend().setAlignment(Qt.AlignLeft)
        else:
            self.chart.legend().setAlignment(Qt.AlignTop)
        
        
        if self._allowHideSeries==True:
            for marker in self.chart.legend().markers():
                try:
                    marker.clicked.disconnect()
                except:
                    pass
                marker.clicked.connect(self.on_marker_clicked)
        
        
        self.repaint()

class VCPie(QChartView):
    def __init__(self):
        QChartView.__init__(self)
        self.setRenderHint(QPainter.Antialiasing)
        self.clear()
        
        
    def save(self, savefile):
        """
            Save view to a file to generate an image file
        """
        pixmap=self.grab()
        pixmap.save(savefile, quality=100)

    def setCurrency(self, currency):
        """
            currency is a Currency Object
        """
        self.currency=currency

    def appendData(self, name, value,  exploded=False):
        slice=self.serie.append(name, value)
        slice.setExploded(exploded)
        slice.setLabelVisible()
        
    def display(self):
        tooltip=""
        c=self.currency.string
        for slice in self.serie.slices():
            tooltip=tooltip+"{}: {} ({})\n".format(slice.label(), c(slice.value()), Percentage(slice.percentage(), 1)).upper()
            slice.setLabel("{}: {}".format(slice.label(), Percentage(slice.percentage(), 1)).upper())
            if slice.percentage()<0.005:
                slice.setLabelVisible(False)
        tooltip=tooltip+"*** Total: {} ***".format(c(self.serie.sum())).upper()
        self.setChart(self.chart)
        self.chart.addSeries(self.serie)
        
        self.setToolTip(tooltip)
        self.repaint()
        
    def clear(self, animations=True):
        self.chart=QChart()
        self.chart.legend().hide()
        font=QFont()
        font.setBold(True)
        font.setPointSize(12)
        self.chart.setTitleFont(font)
        self.chart.layout().setContentsMargins(0,0,0,0);
        if animations==True:
            self.chart.setAnimationOptions(QChart.AllAnimations);
        else:
            self.chart.setAnimationOptions(QChart.NoAnimation)
        self.serie=QPieSeries()
        self.serie.setPieStartAngle(90)
        self.serie.setPieEndAngle(450)




import argparse
from requests import get
from decimal import Decimal
import sys
import logging
from xulpymoney.libxulpymoneyfunctions import addCommonToArgParse, addDebugSystem
from xulpymoney.libxulpymoney import MemSources
        
class CurrentPriceTicker:
    def __init__(self,ticker, xulpymoney, stockmarket):
        self.ticker=ticker
        self.stockmarket=stockmarket
        self.xulpymoney=xulpymoney
        self.dtaware=self.stockmarket.estimated_datetime_for_intraday_quote()
        self.price=None

    def __repr__(self):
        if self.xulpymoney!=None:
            return "PRICE | XULPYMONEY | {} | {} | {}".format(self.xulpymoney, self.dtaware, self.price)
        else:
            return "PRICE | STOCKMARKET | XX | TICKER | {} | {} | {}".format(self.ticker, self.dtaware , self.price)

    def get_price(self):
        url = 'http://www.google.com/search?q={}'.format(self.ticker)    # fails
        web=get(url).text

        if web==None:
            print ("ERROR | FETCHED EMPTY PAGE")
            sys.exit(255)

        if web.find('font-size:157%"><b>')!=-1:
            try:
                web=web.split('font-size:157%"><b>')[1]#Antes
                web=web.split('</span> - <a class="fl"')[0]#Después
                self.price=Decimal(web.split("</b>")[0].replace(".","").replace(",","."))
            except:
                print("ERROR | COULDN'T CONVERT DATETIME {} AND PRICE {}".format(self.dtaware, self.price))
                sys.exit(0)
            return
def main():
    parser=argparse.ArgumentParser()
    parser.add_argument('--TICKER_XULPYMONEY', help='XULPYMONEY code', nargs=2, metavar="VALUE", required=True)
    parser.add_argument('--STOCKMARKET', help='Stock market id', metavar="ID", required=True)
    addCommonToArgParse(parser)
    args=parser.parse_args()        
    addDebugSystem(args)

    mem=MemSources()
    stockmarket=mem.stockmarkets.find_by_id(int(args.STOCKMARKET))
    logging.info(stockmarket)
    s=CurrentPriceTicker(args.TICKER_XULPYMONEY[0], args.TICKER_XULPYMONEY[1], stockmarket)
    s.get_price()
    print(s)




from PyQt5.QtWidgets import QWidget,  QApplication
from PyQt5.QtCore import QRegExp,  Qt
from PyQt5.QtGui import QTextCursor
from xulpymoney.ui.Ui_wdgQuotesUpdate import Ui_wdgQuotesUpdate
from xulpymoney.libxulpymoney import ProductUpdate

class wdgQuotesUpdate(QWidget, Ui_wdgQuotesUpdate):
    def __init__(self, mem,  parent = None, name = None):
        QWidget.__init__(self,  parent)
        self.setupUi(self)
        self.mem=mem
        self.parent=parent
        self.update=ProductUpdate(self.mem)
        self.index=0

    def run(self):
        self.mem.frmMain.setEnabled(False)
        self.mem.frmMain.repaint()
        QApplication.setOverrideCursor(Qt.WaitCursor)
        QApplication.processEvents()
        ##### PROCESS #####
        self.quotes=self.update.run()
        (insertados, ignored, modificados, malos)=self.quotes.save()
        self.mem.con.commit()
        self.txtCR2Q.append(self.update.readResults())
        self.txtCR2Q.append("Quotes added:")
        for q in insertados.arr:
            self.txtCR2Q.append(" - {}".format(q))
        self.txtCR2Q.append("Quoted modified:")
        for q in insertados.arr:
            self.txtCR2Q.append(" - {}".format(q))
        self.mem.data.load()
        
        self.mem.frmMain.setEnabled(True)
        QApplication.restoreOverrideCursor()

    def on_cmdUsed_released(self):
        QApplication.setOverrideCursor(Qt.WaitCursor)
        self.update.setGlobalCommands(all=False)
        self.run()
        QApplication.restoreOverrideCursor()

    def on_cmdAll_released(self):        
        QApplication.setOverrideCursor(Qt.WaitCursor)
        self.update.setGlobalCommands(all=True)
        self.run()
        QApplication.restoreOverrideCursor()
        
    def on_cmdError_released(self):
        self.txtCR2Q.setFocus()
#        self.txtCR2Q.textCursor() = self.txtCR2Q.textCursor()
        # Setup the desired format for matches
#        format = QtGui.QTextCharFormat()
#        format.setBackground(QtGui.QBrush(QtGui.QColor("red")))
        # Setup the regex engine
        regex = QRegExp( "ERROR")
        # Process the displayed document
        self.index = regex.indexIn(self.txtCR2Q.toPlainText(), self.index+1)
        print(self.index,  self.txtCR2Q.textCursor().position())
        if self.index != -1:
            # Select the matched text and apply the desired format
            self.txtCR2Q.textCursor().setPosition(self.index)
            print(self.index,  self.txtCR2Q.textCursor().position())
            print(self.txtCR2Q.textCursor().movePosition(QTextCursor.PreviousWord, QTextCursor.KeepAnchor, 1))
#            cursor.movePosition(QtGui.QTextCursor.EndOfWord, 1)
#            cursor.mergeCharFormat(format)
            # Move to the next match
#            pos = index + regex.matchedLength()
#            index = regex.indexIn(self.toPlainText(), pos)
        else:
            self.txtCR2Q.textCursor().setPosition(self.index)




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/frmDPSAdd.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_frmDPSAdd(object):
    def setupUi(self, frmDPSAdd):
        frmDPSAdd.setObjectName("frmDPSAdd")
        frmDPSAdd.setWindowModality(QtCore.Qt.ApplicationModal)
        frmDPSAdd.resize(408, 364)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/dividends.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        frmDPSAdd.setWindowIcon(icon)
        frmDPSAdd.setModal(True)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(frmDPSAdd)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lbl = QtWidgets.QLabel(frmDPSAdd)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.lbl.setFont(font)
        self.lbl.setStyleSheet("color: rgb(0, 192, 0);")
        self.lbl.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl.setObjectName("lbl")
        self.verticalLayout.addWidget(self.lbl)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.calendar = QtWidgets.QCalendarWidget(frmDPSAdd)
        self.calendar.setObjectName("calendar")
        self.horizontalLayout.addWidget(self.calendar)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_2 = QtWidgets.QLabel(frmDPSAdd)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.txtGross = myQLineEdit(frmDPSAdd)
        self.txtGross.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtGross.setObjectName("txtGross")
        self.horizontalLayout_2.addWidget(self.txtGross)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.cmd = QtWidgets.QPushButton(frmDPSAdd)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmd.setIcon(icon1)
        self.cmd.setObjectName("cmd")
        self.verticalLayout.addWidget(self.cmd)
        self.horizontalLayout_4.addLayout(self.verticalLayout)

        self.retranslateUi(frmDPSAdd)
        QtCore.QMetaObject.connectSlotsByName(frmDPSAdd)
        frmDPSAdd.setTabOrder(self.txtGross, self.cmd)

    def retranslateUi(self, frmDPSAdd):
        _translate = QtCore.QCoreApplication.translate
        frmDPSAdd.setWindowTitle(_translate("frmDPSAdd", "New DPS"))
        self.label_2.setText(_translate("frmDPSAdd", "DPS gross"))
        self.txtGross.setText(_translate("frmDPSAdd", "0"))
        self.cmd.setText(_translate("frmDPSAdd", "Save DPS"))


from xulpymoney.ui.myqlineedit import myQLineEdit
import xulpymoney.images.xulpymoney_rc



from PyQt5.QtCore import pyqtSlot
from PyQt5.QtWidgets import QDialog, QDialogButtonBox
from xulpymoney.libxulpymoney import QuoteAllIntradayManager, SplitManual
import datetime

from xulpymoney.ui.Ui_frmSplitManual import Ui_frmSplitManual

class frmSplitManual(QDialog, Ui_frmSplitManual):
    def __init__(self, mem, product,  parent = None, name = None, modal = False):
        """
        Constructor
        
        @param parent The parent widget of this dialog. (QWidget)
        @param name The name of this dialog. (QString)
        @param modal Flag indicating a modal dialog. (boolean)
        """
        QDialog.__init__(self, parent)
        if name:
            self.setObjectName(name)
        self.mem=mem
        self.product=product
         
        self.setModal(True)
        self.setupUi(self)
        
        self.all=QuoteAllIntradayManager(self.mem)
        self.all.load_from_db(self.product)
        
        self.wdgDtStart.show_microseconds(False)
        self.wdgDtEnd.show_microseconds(False)
        self.wdgDtStart.grp.setTitle(self.tr("Select the day and time of start"))
        self.wdgDtEnd.grp.setTitle(self.tr("Select the day and time of end"))
        self.wdgDtStart.set(self.mem, self.all.first().open().datetime, self.mem.localzone)
        self.wdgDtEnd.set(self.mem, datetime.datetime.now(), self.mem.localzone)
        self.wdgDtStart.changed.connect(self.on_wdgDtStart_changed)
        self.wdgDtEnd.changed.connect(self.on_wdgDtEnd_changed)
        self.split=None
        self.generateExample()
        
        
    def generateExample(self):
        try:
            self.split=SplitManual(self.mem, self.product, self.txtInitial.decimal(), self.txtFinal.decimal(), self.wdgDtStart.datetime(), self.wdgDtEnd.datetime())
            self.lblExample.setText(self.tr("If you have 1000 shares of 10 \u20ac of price, you will have {0:.6f} shares of {1:.6f} \u20ac of price after the {2}".format(self.split.convertShares(1000),self.split.convertPrices(10),  self.split.type())))
            self.buttonbox.button(QDialogButtonBox.Ok).setEnabled(True)
        except:
            self.lblExample.setText("")
            self.buttonbox.button(QDialogButtonBox.Ok).setEnabled(False)
        

    def on_wdgDtEnd_changed(self):
        self.generateExample()
        
    def on_wdgDtStart_changed(self):
        self.generateExample()

    def on_txtInitial_textChanged(self):
        self.generateExample()

    def on_txtFinal_textChanged(self):
        self.generateExample()
        
    @pyqtSlot()
    def on_buttonbox_accepted(self):
        self.split.makeSplit()
        self.accept()#No haría falta pero para recordar que hay buttonbox
        
    @pyqtSlot()
    def on_buttonbox_rejected(self):
        del self.split
        self.reject()#No haría falta pero para recordar que hay buttonbox
    



from PyQt5.QtWidgets import QWidget, QSpacerItem, QSizePolicy
from xulpymoney.ui.Ui_wdgCuriosities import Ui_wdgCuriosities
from xulpymoney.ui.wdgCuriosity import wdgCuriosity
from xulpymoney.libxulpymoney import Assets,  Money, AccountOperationManager

class wdgCuriosities(QWidget, Ui_wdgCuriosities):
    def __init__(self, mem,  parent = None):
        QWidget.__init__(self, parent)
        self.setupUi(self)
        self.mem=mem

        self.mem.data.benchmark.needStatus(2)

        c=wdgCuriosity(self.mem)
        c.setTitle(self.tr("Since when there is data in the database?"))
        c.setText("The first data is from {}".format(Assets(self.mem).first_datetime_with_user_data()))
        self.layout.addWidget(c)

        c=wdgCuriosity(self.mem)
        c.setTitle(self.tr("Which is the investment I gain more money in the last three years?"))
        selected=None
        maxgains=Money(self.mem, 0, self.mem.localcurrency)
        for inv in self.mem.data.investments.arr:
            consolidado=inv.op_historica.consolidado_bruto(type=3)
            if maxgains<consolidado:
                maxgains=consolidado
                selected=inv
        if selected==None:
            c.setText(self.tr("You still hasn't gains"))
        else:
            c.setText(self.tr("The investment I gain more money is {} in {} ({}). I got {}.".format(selected.name,selected.account.name, selected.account.eb.name, maxgains)))
        self.layout.addWidget(c)


        c=wdgCuriosity(self.mem)
        c.setTitle(self.tr("Which is the product I gain more money in the last three years?"))
        c.setText(self.tr(""))
        self.layout.addWidget(c)

        c=wdgCuriosity(self.mem)
        c.setTitle(self.tr("Which is the benchmark highest and lowest price?"))
        if self.mem.data.benchmark.result.ohclDaily.length()==0:
            c.setText(self.tr("Current benchmarck hasn't data."))
        else:            
            highest=self.mem.data.benchmark.result.ohclDaily.highest()
            lowest=self.mem.data.benchmark.result.ohclDaily.lowest()
            c.setText(self.tr("Current benchmarck ({}) highest price is {}. It took place at {}. Lowest price is {} and took place at {}.".format(self.mem.data.benchmark.name,self.mem.data.benchmark.currency.string(highest.high), highest.date, self.mem.data.benchmark.currency.string(lowest.low), lowest.date)))
        self.layout.addWidget(c)

        c=wdgCuriosity(self.mem)
        c.setTitle(self.tr("How many quotes are there in the database?"))
        c.setText(self.tr("There are {} quotes in this Xulpymoney database.".format(self.mem.con.cursor_one_field("select count(*) from quotes"))))
        self.layout.addWidget(c)

        c=wdgCuriosity(self.mem)
        c.setTitle(self.tr("Which product has the highest quote?"))
        c.setText(self.tr(""))
        self.layout.addWidget(c)

        c=wdgCuriosity(self.mem)
        operations=AccountOperationManager(self.mem)
        operations.load_from_db("select * from opercuentas where importe = (select max(importe) from opercuentas) order by datetime desc limit 1")
        c.setTitle(self.tr("Which is the amount of the largest account operation?"))
        if operations.length()==1:
            o=operations.only()
            c.setText(self.tr("The largest account operation took place at {}. It's concept was '{}' and it's amount was {}.".format(o.datetime, o.concepto.name, o.account.currency.string(o.importe))))
        else:
            c.setText(self.tr("There are not account operations yet."))
        self.layout.addWidget(c)

        c=wdgCuriosity(self.mem)
        c.setTitle(self.tr("Which is the amount of the largest credit card operation?"))
        c.setText(self.tr(""))
        self.layout.addWidget(c)

        c=wdgCuriosity(self.mem)
        c.setTitle(self.tr("Which is the amount of the largest investment operation?"))
        c.setText(self.tr(""))
        self.layout.addWidget(c)
        self.layout.addSpacerItem(QSpacerItem(10, 10, QSizePolicy.Expanding, QSizePolicy.Expanding))



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/wdgQuotesUpdate.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_wdgQuotesUpdate(object):
    def setupUi(self, wdgQuotesUpdate):
        wdgQuotesUpdate.setObjectName("wdgQuotesUpdate")
        wdgQuotesUpdate.resize(1109, 795)
        self.horizontalLayout = QtWidgets.QHBoxLayout(wdgQuotesUpdate)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.cmdUsed = QtWidgets.QPushButton(wdgQuotesUpdate)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/transfer.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdUsed.setIcon(icon)
        self.cmdUsed.setObjectName("cmdUsed")
        self.horizontalLayout_3.addWidget(self.cmdUsed)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.cmdAll = QtWidgets.QPushButton(wdgQuotesUpdate)
        self.cmdAll.setIcon(icon)
        self.cmdAll.setObjectName("cmdAll")
        self.horizontalLayout_3.addWidget(self.cmdAll)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.tab = QtWidgets.QTabWidget(wdgQuotesUpdate)
        self.tab.setObjectName("tab")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.tab_4)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.txtCR2Q = QtWidgets.QTextBrowser(self.tab_4)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setBold(True)
        font.setWeight(75)
        self.txtCR2Q.setFont(font)
        self.txtCR2Q.setUndoRedoEnabled(True)
        self.txtCR2Q.setLineWrapMode(QtWidgets.QTextEdit.NoWrap)
        self.txtCR2Q.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByKeyboard|QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextBrowserInteraction|QtCore.Qt.TextEditable|QtCore.Qt.TextEditorInteraction|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.txtCR2Q.setObjectName("txtCR2Q")
        self.verticalLayout_2.addWidget(self.txtCR2Q)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem3)
        self.cmdError = QtWidgets.QPushButton(self.tab_4)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/eye_red.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdError.setIcon(icon1)
        self.cmdError.setObjectName("cmdError")
        self.horizontalLayout_2.addWidget(self.cmdError)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem4)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_4.addLayout(self.verticalLayout_2)
        self.tab.addTab(self.tab_4, "")
        self.verticalLayout.addWidget(self.tab)
        self.horizontalLayout.addLayout(self.verticalLayout)

        self.retranslateUi(wdgQuotesUpdate)
        self.tab.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(wdgQuotesUpdate)

    def retranslateUi(self, wdgQuotesUpdate):
        _translate = QtCore.QCoreApplication.translate
        self.cmdUsed.setText(_translate("wdgQuotesUpdate", "Update used products"))
        self.cmdAll.setText(_translate("wdgQuotesUpdate", "Update all products"))
        self.cmdError.setText(_translate("wdgQuotesUpdate", "Next error"))
        self.tab.setTabText(self.tab.indexOf(self.tab_4), _translate("wdgQuotesUpdate", "Update results"))


import xulpymoney.images.xulpymoney_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/wdgOrdersAdd.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_wdgOrdersAdd(object):
    def setupUi(self, wdgOrdersAdd):
        wdgOrdersAdd.setObjectName("wdgOrdersAdd")
        wdgOrdersAdd.resize(510, 328)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/bank.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        wdgOrdersAdd.setWindowIcon(icon)
        self.horizontalLayout = QtWidgets.QHBoxLayout(wdgOrdersAdd)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lbl = QtWidgets.QLabel(wdgOrdersAdd)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.lbl.setFont(font)
        self.lbl.setText("")
        self.lbl.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl.setObjectName("lbl")
        self.verticalLayout.addWidget(self.lbl)
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.label = QtWidgets.QLabel(wdgOrdersAdd)
        self.label.setObjectName("label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label)
        self.cmbInvestments = QtWidgets.QComboBox(wdgOrdersAdd)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbInvestments.sizePolicy().hasHeightForWidth())
        self.cmbInvestments.setSizePolicy(sizePolicy)
        self.cmbInvestments.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContents)
        self.cmbInvestments.setObjectName("cmbInvestments")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.cmbInvestments)
        self.label_2 = QtWidgets.QLabel(wdgOrdersAdd)
        self.label_2.setObjectName("label_2")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_2)
        self.deDate = QtWidgets.QDateEdit(wdgOrdersAdd)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.deDate.sizePolicy().hasHeightForWidth())
        self.deDate.setSizePolicy(sizePolicy)
        self.deDate.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.deDate.setCalendarPopup(True)
        self.deDate.setObjectName("deDate")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.deDate)
        self.label_3 = QtWidgets.QLabel(wdgOrdersAdd)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.deExpiration = QtWidgets.QDateEdit(wdgOrdersAdd)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.deExpiration.sizePolicy().hasHeightForWidth())
        self.deExpiration.setSizePolicy(sizePolicy)
        self.deExpiration.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.deExpiration.setCalendarPopup(True)
        self.deExpiration.setObjectName("deExpiration")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.deExpiration)
        self.label_4 = QtWidgets.QLabel(wdgOrdersAdd)
        self.label_4.setObjectName("label_4")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.txtShares = myQLineEdit(wdgOrdersAdd)
        self.txtShares.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtShares.setObjectName("txtShares")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.txtShares)
        self.label_5 = QtWidgets.QLabel(wdgOrdersAdd)
        self.label_5.setObjectName("label_5")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.label_5)
        self.txtPrice = myQLineEdit(wdgOrdersAdd)
        self.txtPrice.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtPrice.setObjectName("txtPrice")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.txtPrice)
        self.label_6 = QtWidgets.QLabel(wdgOrdersAdd)
        self.label_6.setObjectName("label_6")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.label_6)
        self.txtAmount = myQLineEdit(wdgOrdersAdd)
        self.txtAmount.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtAmount.setObjectName("txtAmount")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.txtAmount)
        self.verticalLayout.addLayout(self.formLayout)
        self.buttonbox = QtWidgets.QDialogButtonBox(wdgOrdersAdd)
        self.buttonbox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonbox.setCenterButtons(True)
        self.buttonbox.setObjectName("buttonbox")
        self.verticalLayout.addWidget(self.buttonbox)
        self.horizontalLayout.addLayout(self.verticalLayout)

        self.retranslateUi(wdgOrdersAdd)
        QtCore.QMetaObject.connectSlotsByName(wdgOrdersAdd)

    def retranslateUi(self, wdgOrdersAdd):
        _translate = QtCore.QCoreApplication.translate
        self.label.setText(_translate("wdgOrdersAdd", "Active investment"))
        self.label_2.setText(_translate("wdgOrdersAdd", "Order date"))
        self.deDate.setDisplayFormat(_translate("wdgOrdersAdd", "yyyy/MM/dd"))
        self.label_3.setText(_translate("wdgOrdersAdd", "Order expiration date"))
        self.deExpiration.setDisplayFormat(_translate("wdgOrdersAdd", "yyyy/MM/dd"))
        self.label_4.setText(_translate("wdgOrdersAdd", "Shares number"))
        self.txtShares.setText(_translate("wdgOrdersAdd", "0"))
        self.label_5.setText(_translate("wdgOrdersAdd", "Price"))
        self.txtPrice.setText(_translate("wdgOrdersAdd", "0"))
        self.label_6.setText(_translate("wdgOrdersAdd", "Amount"))
        self.txtAmount.setText(_translate("wdgOrdersAdd", "0"))


from xulpymoney.ui.myqlineedit import myQLineEdit
import xulpymoney.images.xulpymoney_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/frmEstimationsAdd.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_frmEstimationsAdd(object):
    def setupUi(self, frmEstimationsAdd):
        frmEstimationsAdd.setObjectName("frmEstimationsAdd")
        frmEstimationsAdd.setWindowModality(QtCore.Qt.ApplicationModal)
        frmEstimationsAdd.resize(634, 177)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/dinero.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        frmEstimationsAdd.setWindowIcon(icon)
        frmEstimationsAdd.setModal(True)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(frmEstimationsAdd)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lbl = QtWidgets.QLabel(frmEstimationsAdd)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.lbl.setFont(font)
        self.lbl.setStyleSheet("color: rgb(0, 192, 0);")
        self.lbl.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl.setObjectName("lbl")
        self.verticalLayout.addWidget(self.lbl)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(frmEstimationsAdd)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.txtYear = QtWidgets.QLineEdit(frmEstimationsAdd)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtYear.sizePolicy().hasHeightForWidth())
        self.txtYear.setSizePolicy(sizePolicy)
        self.txtYear.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtYear.setObjectName("txtYear")
        self.horizontalLayout.addWidget(self.txtYear)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lblEstimation = QtWidgets.QLabel(frmEstimationsAdd)
        self.lblEstimation.setObjectName("lblEstimation")
        self.horizontalLayout_2.addWidget(self.lblEstimation)
        self.txtDPA = myQLineEdit(frmEstimationsAdd)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtDPA.sizePolicy().hasHeightForWidth())
        self.txtDPA.setSizePolicy(sizePolicy)
        self.txtDPA.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtDPA.setObjectName("txtDPA")
        self.horizontalLayout_2.addWidget(self.txtDPA)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_3 = QtWidgets.QLabel(frmEstimationsAdd)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_3.addWidget(self.label_3)
        self.cmbSource = QtWidgets.QComboBox(frmEstimationsAdd)
        self.cmbSource.setObjectName("cmbSource")
        self.horizontalLayout_3.addWidget(self.cmbSource)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.cmd = QtWidgets.QPushButton(frmEstimationsAdd)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmd.setIcon(icon1)
        self.cmd.setObjectName("cmd")
        self.verticalLayout.addWidget(self.cmd)
        self.horizontalLayout_4.addLayout(self.verticalLayout)

        self.retranslateUi(frmEstimationsAdd)
        QtCore.QMetaObject.connectSlotsByName(frmEstimationsAdd)
        frmEstimationsAdd.setTabOrder(self.txtDPA, self.txtYear)
        frmEstimationsAdd.setTabOrder(self.txtYear, self.cmbSource)
        frmEstimationsAdd.setTabOrder(self.cmbSource, self.cmd)

    def retranslateUi(self, frmEstimationsAdd):
        _translate = QtCore.QCoreApplication.translate
        frmEstimationsAdd.setWindowTitle(_translate("frmEstimationsAdd", "New estimation"))
        self.label.setText(_translate("frmEstimationsAdd", "Add a year"))
        self.lblEstimation.setText(_translate("frmEstimationsAdd", "Add a estimation"))
        self.txtDPA.setText(_translate("frmEstimationsAdd", "0"))
        self.label_3.setText(_translate("frmEstimationsAdd", "Add a source"))
        self.cmd.setText(_translate("frmEstimationsAdd", "Save estimation"))


from xulpymoney.ui.myqlineedit import myQLineEdit
import xulpymoney.images.xulpymoney_rc
